/*
 * arch/arm/mach-shmobile/board-rma1evb.c
 *
 * Copyright (C) 2011  Renesas Electronics Corporation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <linux/kernel.h>
#include <linux/init.h>
#include <linux/interrupt.h>
#include <linux/irq.h>
#include <linux/platform_device.h>
#include <linux/delay.h>
#include <linux/io.h>
#include <linux/i2c.h>
#include <linux/dma-mapping.h>
#include <linux/serial_sci.h>
#include <linux/smsc911x.h>
#include <linux/gpio.h>
#include <linux/input.h>
#include <linux/input/rma1evb_btn.h>
#include <linux/mmc/host.h>
#include <linux/mmc/sh_mmcif.h>
#include <linux/mmc/sh_mobile_sdhi.h>
#include <linux/mfd/tmio.h>
#include <linux/spi/spi.h>
#include <linux/spi/sh_msiof.h>
#include <linux/usb/r8a66597.h>
#include <linux/usb/rmobile.h>
#include <media/sh_mobile_ceu.h>
#include <media/soc_camera.h>
#include <media/soc_camera_platform.h>

#include <video/sh_mobile_lcdc.h>
#include <sound/sh_fsi.h>

#include <mach/common.h>
#include <mach/sh7740.h>
#include <asm/mach-types.h>
#include <asm/mach/arch.h>
#include <asm/mach/map.h>
#include <asm/mach/time.h>
#include <asm/hardware/cache-l2x0.h>

/* FPGA control */
#define FPGA_IRQ_BASE	(irqpin2irq(31) + 1)
#define fpga2irq(nr)	(FPGA_IRQ_BASE + (nr))

#include "board-rma1evb_fpga.c"
#include "board-rma1evb_pwic.c"

static struct rma1evb_btn_info keysc_info = {
	.scan_interval	= 30,
	.keycodes = {
		KEY_POWER, KEY_ENTER, KEY_DOWN, KEY_UP,
		KEY_RIGHT, KEY_LEFT, KEY_BACK, KEY_MENU
	},
};

static struct resource keysc_resources[] = {
	[0] = {
		.start  = fpga2irq(IRQ_PSW),
		.flags  = IORESOURCE_IRQ,
	},
};

static struct platform_device keysc_device = {
	.name           = "rma1evb_btn",
	.id             = -1,
	.dev		= {
		.platform_data	= &keysc_info,
	},
	.num_resources  = ARRAY_SIZE(keysc_resources),
	.resource       = keysc_resources,
};

static struct resource smsc9221_resources[] = {
	[0] = {
		.start		= 0x18010000,
		.end		= 0x18010000 + SZ_4K - 1,
		.flags		= IORESOURCE_MEM,
	},
	[1] = {
		.start		= fpga2irq(IRQ_ETH),
		.flags		= IORESOURCE_IRQ,
	},
};

static struct smsc911x_platform_config smsc9221_platdata = {
	.flags		= SMSC911X_USE_16BIT,
	.phy_interface	= PHY_INTERFACE_MODE_MII,
	.irq_polarity	= SMSC911X_IRQ_POLARITY_ACTIVE_LOW,
	.irq_type	= SMSC911X_IRQ_TYPE_PUSH_PULL,
};

static struct platform_device eth_device = {
	.name		= "smsc911x",
	.id		= 0,
	.dev  = {
		.platform_data = &smsc9221_platdata,
	},
	.resource	= smsc9221_resources,
	.num_resources	= ARRAY_SIZE(smsc9221_resources),
};

static void sdhi0_set_pwr(struct platform_device *pdev, int state)
{
	gpio_set_value(GPIO_PORT107, state);
	gpio_set_value(GPIO_PORT89, state);
}

static struct sh_mobile_sdhi_info sdhi0_info = {
	.dma_slave_tx	= SHDMA_SLAVE_SDHI0_TX,
	.dma_slave_rx	= SHDMA_SLAVE_SDHI0_RX,
	.tmio_caps	= MMC_CAP_SD_HIGHSPEED | MMC_CAP_SDIO_IRQ,
	.tmio_ocr_mask	= MMC_VDD_165_195 | MMC_VDD_32_33 | MMC_VDD_33_34,
	.set_pwr	= sdhi0_set_pwr,
};

static struct resource sdhi0_resources[] = {
	[0] = {
		.name	= "SDHI0",
		.start	= 0xe6850000,
		.end	= 0xe68500ff,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(117),
		.flags	= IORESOURCE_IRQ,
	},
	[2] = {
		.start	= gic_spi(118),
		.flags	= IORESOURCE_IRQ,
	},
	[3] = {
		.start	= gic_spi(119),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device sdhi0_device = {
	.name		= "sh_mobile_sdhi",
	.id		= 0,
	.dev		= {
		.platform_data	= &sdhi0_info,
	},
	.num_resources	= ARRAY_SIZE(sdhi0_resources),
	.resource	= sdhi0_resources,
};

static void sdhi2_set_pwr(struct platform_device *pdev, int state)
{
	fpga_write(FPGA_SD2PWCR, state ? 1 : 0, 1);
}

static struct sh_mobile_sdhi_info sh_sdhi2_platdata = {
	.dma_slave_tx	= SHDMA_SLAVE_SDHI2_TX,
	.dma_slave_rx	= SHDMA_SLAVE_SDHI2_RX,
	.tmio_caps	= MMC_CAP_SD_HIGHSPEED | MMC_CAP_SDIO_IRQ,
	.tmio_ocr_mask	= MMC_VDD_32_33 | MMC_VDD_33_34,
	.set_pwr	= sdhi2_set_pwr,
};

static struct resource sdhi2_resources[] = {
	[0] = {
		.name	= "SDHI2",
		.start	= 0xe6870000,
		.end	= 0xe68700ff,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(125),
		.flags	= IORESOURCE_IRQ,
	},
	[2] = {
		.start	= gic_spi(126),
		.flags	= IORESOURCE_IRQ,
	},
	[3] = {
		.start	= gic_spi(127),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device sdhi2_device = {
	.name		= "sh_mobile_sdhi",
	.id		= 2,
	.dev		= {
		.platform_data	= &sh_sdhi2_platdata,
	},
	.num_resources	= ARRAY_SIZE(sdhi2_resources),
	.resource	= sdhi2_resources,
};

static struct resource sh_mmcif_resources[] = {
	[0] = {
		.name	= "MMCIF",
		.start	= 0xe6bd0000,
		.end	= 0xe6bd00ff,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		/* MMC ERR */
		.start	= gic_spi(56),
		.flags	= IORESOURCE_IRQ,
	},
	[2] = {
		/* MMC NOR */
		.start	= gic_spi(57),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct sh_mmcif_dma sh_mmcif_dma = {
	.chan_priv_rx	= {
		.slave_id	= SHDMA_SLAVE_MMCIF_RX,
	},
	.chan_priv_tx	= {
		.slave_id	= SHDMA_SLAVE_MMCIF_TX,
	},
};

static void sh_mmcif_set_pwr(struct platform_device *pdev, int state)
{
	fpga_write(FPGA_MMCPWCR, state ? 1 : 0, 1);
}

static struct sh_mmcif_plat_data sh_mmcif_plat = {
	.sup_pclk	= 0,
	.ocr		= MMC_VDD_165_195 | MMC_VDD_32_33 | MMC_VDD_33_34,
	.caps		= MMC_CAP_4_BIT_DATA | MMC_CAP_8_BIT_DATA |
			  MMC_CAP_NONREMOVABLE,
	.dma		= &sh_mmcif_dma,
	.set_pwr	= sh_mmcif_set_pwr,
};

static struct platform_device sh_mmcif_device = {
	.name		= "sh_mmcif",
	.id		= 0,
	.dev		= {
		.platform_data	= &sh_mmcif_plat,
	},
	.num_resources	= ARRAY_SIZE(sh_mmcif_resources),
	.resource	= sh_mmcif_resources,
};

static struct sh_msiof_spi_info sh_msiof0_info = {
	.rx_fifo_override	= 256,
	.num_chipselect		= 1,
};

static struct resource sh_msiof0_resources[] = {
	[0] = {
		.start	= 0xfff10000,
		.end	= 0xfff10064 - 1,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(213),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device sh_msiof0_device = {
	.name		= "spi_sh_msiof",
	.id		= 0,
	.dev		= {
		.platform_data	= &sh_msiof0_info,
	},
	.num_resources	= ARRAY_SIZE(sh_msiof0_resources),
	.resource	= sh_msiof0_resources,
};

static struct sh_fsi_dma sh_fsi2_dma = {
	.dma_porta_tx = {
		.slave_id	= SHDMA_SLAVE_FSIA_TX,
	},
	.dma_porta_rx = {
		.slave_id	= SHDMA_SLAVE_FSIA_RX,
	},
	.dma_portb_rx = {
		.slave_id	= SHDMA_SLAVE_FSIB_RX,
	},
};

static struct sh_fsi_platform_info fsi_info = {
	.porta_flags =
#ifndef CONFIG_SND_SOC_SH4_FSI_MASTER
			SH_FSI_OUT_SLAVE_MODE	|
			SH_FSI_IN_SLAVE_MODE	|
#endif
			SH_FSI_BRM_INV		|
			SH_FSI_BRS_INV		|
			SH_FSI_OFMT(I2S)	|
			SH_FSI_IFMT(I2S),
#ifdef CONFIG_SND_SOC_SH4_FSI_MASTER
	.porta_flags2 =
		SH_FSI_LRCLK_256	|
		SH_FSI_BITCLK_64,
#endif
	.dma = &sh_fsi2_dma,
};

static struct resource fsi_resources[] = {
	[0] = {
		.name	= "FSI",
		.start	= 0xfe1f0000,
		.end	= 0xfe1f0400 - 1,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start  = gic_spi(9),
		.flags  = IORESOURCE_IRQ,
	},
};

static struct platform_device fsi_device = {
	.name		= "sh_fsi2",
	.id		= 0,
	.num_resources	= ARRAY_SIZE(fsi_resources),
	.resource	= fsi_resources,
	.dev	= {
		.platform_data	= &fsi_info,
	},
};

static struct resource fmsi_resources[] = {
	[0] = {
		.name	= "FMSI",
		.start	= 0xfe200000,
		.end	= 0xfe400000,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		/* SPU2-DSP0 */
		.start  = gic_spi(6),
		.flags  = IORESOURCE_IRQ,
	},
	[2] = {
		/* SPU2-DSP1 */
		.start  = gic_spi(7),
		.flags  = IORESOURCE_IRQ,
	},
};

static struct platform_device fmsi_device = {
	.name		= "sh_fmsi",
	.id		= 0,
	.num_resources	= ARRAY_SIZE(fmsi_resources),
	.resource	= fmsi_resources,
};

#define USBCR1		0xe605810a
#define USBH_USBCTR	0xf6710834
static struct clk *usb_clk, *usbp_clk, *usbh_clk, *usbphy_clk;
static DEFINE_SPINLOCK(usb_lock);
static void usb_common_clock(int on)
{
	static int count = 0;
	unsigned long flags;

	spin_lock_irqsave(&usb_lock, flags);
	if (on && !count) {
		clk_enable(usb_clk);
		clk_enable(usbp_clk);
		clk_enable(usbh_clk);
		clk_enable(usbphy_clk);
		__raw_writew(0x6b50, USBCR1);
		mdelay(1);
		__raw_writel(0x0000040c, USBH_USBCTR);
		__raw_writel(0x00000408, USBH_USBCTR);
	}

	count = on ? count+1 : count-1;
	if (count < 0) {
		printk(KERN_ERR "%s: count error\n", __func__);
		count = 0;
		spin_unlock_irqrestore(&usb_lock, flags);
		return;
	}

	if (!on && !count) {
		__raw_writel(0x0000010f, USBH_USBCTR);
		__raw_writew(0x6bc0, USBCR1);
		clk_disable(usbphy_clk);
		clk_disable(usbh_clk);
		clk_disable(usbp_clk);
		clk_disable(usb_clk);
	}
	spin_unlock_irqrestore(&usb_lock, flags);
}

static struct rmobile_usb_platdata usb_pdata = {
	.common_clock	= usb_common_clock,
};

static u64 usb_dmamask = DMA_BIT_MASK(32);

static struct resource ohci_resources[] = {
	[0] = {
		.start	= 0xc6700000,
		.end	= 0xc6720000 - 1,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(234),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device ohci_device = {
	.name	= "rmobile-ohci-driver",
	.id	= 0,
	.dev	= {
		.dma_mask		= &usb_dmamask,
		.coherent_dma_mask	= DMA_BIT_MASK(32),
		.platform_data		= &usb_pdata,
	},
	.num_resources	= ARRAY_SIZE(ohci_resources),
	.resource	= ohci_resources,
};

static struct resource ehci_resources[] = {
	[0] = {
		.start	= 0xc6700000,
		.end	= 0xc6720000 - 1,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(234),
		.flags	= IORESOURCE_IRQ,
	},
};
static struct platform_device ehci_device = {
	.name	= "rmobile-ehci-driver",
	.id	= 0,
	.dev	= {
		.dma_mask		= &usb_dmamask,
		.coherent_dma_mask	= DMA_BIT_MASK(32),
		.platform_data		= &usb_pdata,
	},
	.num_resources	= ARRAY_SIZE(ehci_resources),
	.resource	= ehci_resources,
};

static struct sh_mobile_lcdc_info lcdc_info = {
	.clock_source	= LCDC_CLK_BUS,

	/* LCDC0 */
	.ch[0] = {
		.chan = LCDC_CHAN_MAINLCD,
		.bpp = 32,
		.interface_type		= RGB24,
		.clock_divider		= 5,
		.flags			= 0,
		.lcd_cfg = {
			.name		= "WVGA Panel",
			.xres		= 800,
			.yres		= 480,
			.left_margin	= 88,
			.right_margin	= 40,
			.hsync_len	= 128,
			.upper_margin	= 20,
			.lower_margin	= 5,
			.vsync_len	= 5,
			.sync		= 0,
		},
		.lcd_size_cfg = {
			.width	= 111,
			.height = 68,
		},
	},
};

static struct resource lcdc_resources[] = {
	[0] = {
		.name	= "LCDC",
		.start	= 0xfe940000,
		.end	= 0xfe943fff,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(177),
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device lcdc_device = {
	.name		= "sh_mobile_lcdc_fb",
	.num_resources	= ARRAY_SIZE(lcdc_resources),
	.resource	= lcdc_resources,
	.dev	= {
		.platform_data	= &lcdc_info,
		.coherent_dma_mask = ~0,
	},
};

static struct i2c_board_info i2c_cameras[] = {
	{
		I2C_BOARD_INFO("ov5642", 0x3c),
	},
	{
		I2C_BOARD_INFO("ak8854", 0x44),
	},
	{
		I2C_BOARD_INFO("ce150x", 0x3c),
	},
};

#if defined(CONFIG_VIDEO_OV5642) || defined(CONFIG_VIDEO_OV5642_MODULE)
static struct soc_camera_link outcamera_link = {
	.bus_id		= 0,
	.module_name	= "ov5642",
	.i2c_adapter_id	= 0,
	.board_info	= &i2c_cameras[0],
};
#endif
#if defined(CONFIG_VIDEO_AK8854) || defined(CONFIG_VIDEO_AK8854_MODULE)
static struct soc_camera_link outcamera_link = {
	.bus_id		= 0,
	.module_name	= "ak8854",
	.i2c_adapter_id	= 1,
	.board_info	= &i2c_cameras[1],
};
#endif
#if defined(CONFIG_VIDEO_CE150X) || defined(CONFIG_VIDEO_CE150X_MODULE)
static struct soc_camera_link outcamera_link = {
	.bus_id		= 0,
	.module_name	= "ce150x",
	.i2c_adapter_id	= 0,
	.board_info	= &i2c_cameras[2],
};
#endif

static struct platform_device outcamera_device = {
	.name   = "soc-camera-pdrv",
	.id     = 0,
	.dev    = {
#if defined(CONFIG_VIDEO_OV5642) || defined(CONFIG_VIDEO_OV5642_MODULE) || \
    defined(CONFIG_VIDEO_AK8854) || defined(CONFIG_VIDEO_AK8854_MODULE) || \
    defined(CONFIG_VIDEO_CE150X) || defined(CONFIG_VIDEO_CE150X_MODULE)
		.platform_data = &outcamera_link,
#endif
	},
};

static struct sh_mobile_ceu_info sh_mobile_ceu0_info = {
#if defined(CONFIG_VIDEO_CE150X) || defined(CONFIG_VIDEO_CE150X_MODULE)
	.flags = SH_CEU_FLAG_USE_16BIT_BUS,
#else
	.flags = SH_CEU_FLAG_USE_8BIT_BUS | SH_CEU_FLAG_USE_LOWER_8BIT_BUS,
#endif
	.csi2_dev = NULL,
};

static struct resource ceu0_resources[] = {
	[0] = {
		.name	= "CEU0",
		.start	= 0xfe910000,
		.end	= 0xfe9100ab,
		.flags	= IORESOURCE_MEM,
	},
	[1] = {
		.start	= gic_spi(160),
		.flags  = IORESOURCE_IRQ,
	},
	[2] = {
		/* place holder for contiguous memory */
	},
};

static struct platform_device ceu0_device = {
	.name		= "sh_mobile_ceu",
	.id             = 0, /* "ceu0" clock */
	.num_resources	= ARRAY_SIZE(ceu0_resources),
	.resource	= ceu0_resources,
	.dev	= {
		.platform_data	= &sh_mobile_ceu0_info,
		.coherent_dma_mask = DMA_BIT_MASK(32),
	},
};

static struct platform_device *rma1evb_devices[] __initdata = {
	&keysc_device,
	&eth_device,
	&sh_mmcif_device,
	&sdhi0_device,
	&sdhi2_device,
	&sh_msiof0_device,
	&ohci_device,
	&ehci_device,
	&lcdc_device,
	&fsi_device,
	&fmsi_device,
	&ceu0_device,
	&outcamera_device,
};

/* I2C devices */
static struct i2c_board_info i2c0_devices[] = {
	{
		I2C_BOARD_INFO("pmic-as3608", 0x46),
		.irq = fpga2irq(IRQ_PMIC),
	},
	{
		I2C_BOARD_INFO("st1232-ts", 0x55),
		.irq = fpga2irq(IRQ_TP0),
	},
	{
		I2C_BOARD_INFO("m41t80", 0x68),
		.irq = fpga2irq(IRQ_RTC),
	},
};

static struct i2c_board_info i2c1_devices[] = {
	{
		I2C_BOARD_INFO("ak4648", 0x12),
	},
};

static struct map_desc rma1evb_io_desc[] __initdata = {
	/* 0xe6000000-0xf0ffffff -> 0xe6000000-0xf0ffffff (Peri) */
	{
		.virtual	= 0xe6000000,
		.pfn		= __phys_to_pfn(0xe6000000),
		.length		= 176 << 20,
		.type		= MT_DEVICE_NONSHARED
	},
	/* 0xc1000000-0xc7ffffff -> 0xf1000000-0xf7ffffff (AXI Peri) */
	{
		.virtual	= 0xf1000000,
		.pfn		= __phys_to_pfn(0xc1000000),
		.length		= 112 << 20,
		.type		= MT_DEVICE_NONSHARED
	},
};

static void __init rma1evb_map_io(void)
{
	iotable_init(rma1evb_io_desc, ARRAY_SIZE(rma1evb_io_desc));

	/* setup early devices and console here as well */
	sh7740_add_early_devices();
	shmobile_setup_console();
}

void __init rma1evb_init_irq(void)
{
	sh7740_init_irq();
	fpga_init();
}

#define RESCNT2		0xe6188020

void rma1evb_arch_reset(char mode, const char *cmd)
{
	__raw_writel(__raw_readl(RESCNT2) | (1 << 31), RESCNT2);
}

#define GPIO_PORT7CR	0xe6050007
#define GPIO_PORT8CR	0xe6050008
#define GPIO_PORT12CR	0xe605000c
#define GPIO_PORT13CR	0xe605000d

static void __init gpio_no_direction(u32 addr)
{
	__raw_writeb(0x00, addr);
}

static void __init rma1evb_init(void)
{
	struct clk *sub_clk = clk_get(NULL, "sub_clk");
	struct clk *sub2_clk = clk_get(NULL, "sub2_clk");
	struct clk *pllc1_div2 = clk_get(NULL, "pllc1_div2_clk");
	struct clk *usb24s_div2 = clk_get(NULL, "usb24s_div2");
	struct clk *fsiack_clk = clk_get(NULL, "fsiack_clk");
	struct clk *fsia_clk = clk_get(NULL, "fsia_clk");
	struct clk *fmsock_clk = clk_get(NULL, "fmsock_clk");
	struct clk *fmso_clk = clk_get(NULL, "fmso_clk");

	unsigned long rate;
	struct clk *clk;

	clk_set_parent(sub_clk, pllc1_div2);
	clk_set_parent(sub2_clk, pllc1_div2);
	rate = clk_round_rate(sub_clk, 50000000);
	clk_set_rate(sub_clk, rate);
	clk_set_rate(sub2_clk, rate);
	clk_put(sub_clk);
	clk_put(sub2_clk);
	clk_put(pllc1_div2);

	shmobile_arch_reset = rma1evb_arch_reset;

	sh7740_pinmux_init();

	/* SCIFA5 */
	gpio_request(GPIO_FN_PORT91_SCIFA5_TXD, NULL);
	gpio_request(GPIO_FN_PORT92_SCIFA5_RXD, NULL);

	/* SDHI0 */
	gpio_request(GPIO_FN_SDHICMD0, NULL);
	gpio_request(GPIO_FN_SDHICLK0, NULL);
	gpio_request(GPIO_FN_SDHID0_0, NULL);
	gpio_request(GPIO_FN_SDHID0_1, NULL);
	gpio_request(GPIO_FN_SDHID0_2, NULL);
	gpio_request(GPIO_FN_SDHID0_3, NULL);
	gpio_request(GPIO_FN_SDHICD0, NULL);
	gpio_request(GPIO_FN_SDHIWP0, NULL);
	gpio_request(GPIO_PORT89, NULL);	/* SDCARD_PON */
	gpio_direction_output(GPIO_PORT89, 0);
	gpio_request(GPIO_PORT107, NULL);	/* SDHI033_PON */
	gpio_direction_output(GPIO_PORT107, 0);
	gpio_request(GPIO_PORT108, NULL);	/* SDHI018_PON */
	gpio_direction_output(GPIO_PORT108, 0);

	/* SDHI2 */
	gpio_request(GPIO_FN_SDHICLK2, NULL);
	gpio_request(GPIO_FN_SDHICMD2, NULL);
	gpio_request(GPIO_FN_SDHID2_0, NULL);
	gpio_request(GPIO_FN_SDHID2_1, NULL);
	gpio_request(GPIO_FN_SDHID2_2, NULL);
	gpio_request(GPIO_FN_SDHID2_3, NULL);
	gpio_request(GPIO_FN_SDHID0_3, NULL);
	gpio_request(GPIO_FN_PORT202_SDHICD2, NULL);
	gpio_request(GPIO_FN_PORT177_SDHIWP2, NULL);

	/* MMCIF */
	gpio_request(GPIO_FN_PORT66_MMCCLK0, NULL);
	gpio_request(GPIO_FN_PORT67_MMCCMD0, NULL);
	gpio_request(GPIO_FN_PORT68_MMCD0_0, NULL);
	gpio_request(GPIO_FN_PORT69_MMCD0_1, NULL);
	gpio_request(GPIO_FN_PORT70_MMCD0_2, NULL);
	gpio_request(GPIO_FN_PORT71_MMCD0_3, NULL);
	gpio_request(GPIO_FN_PORT72_MMCD0_4, NULL);
	gpio_request(GPIO_FN_PORT73_MMCD0_5, NULL);
	gpio_request(GPIO_FN_PORT74_MMCD0_6, NULL);
	gpio_request(GPIO_FN_PORT75_MMCD0_7, NULL);

	/* MSIOF0 */
	gpio_request(GPIO_FN_MSIOF0_SS2, NULL);
	gpio_request(GPIO_FN_MSIOF0_SS1, NULL);
	gpio_request(GPIO_FN_MSIOF0_MCK1, NULL);
	gpio_request(GPIO_FN_MSIOF0_MCK0, NULL);
	gpio_request(GPIO_FN_MSIOF0_RSYNC, NULL);
	gpio_request(GPIO_FN_MSIOF0_RSCK, NULL);
	gpio_request(GPIO_FN_MSIOF0_RXD, NULL);
	gpio_request(GPIO_FN_MSIOF0_TSCK, NULL);
	gpio_request(GPIO_FN_MSIOF0_TSCK, NULL);
	gpio_request(GPIO_FN_MSIOF0_TXD, NULL);

	/* LCDC0 */
	gpio_request(GPIO_FN_PORT159_LCDD23_0,   NULL);
	gpio_request(GPIO_FN_PORT160_LCDD22_0,   NULL);
	gpio_request(GPIO_FN_PORT158_LCDD21_0,   NULL);
	gpio_request(GPIO_FN_PORT161_LCDD20_0,   NULL);
	gpio_request(GPIO_FN_PORT162_LCDD19_0,   NULL);
	gpio_request(GPIO_FN_PORT163_LCDD18_0,   NULL);
	gpio_request(GPIO_FN_LCDD17_0,   NULL);
	gpio_request(GPIO_FN_LCDD16_0,   NULL);
	gpio_request(GPIO_FN_LCDD15_0,   NULL);
	gpio_request(GPIO_FN_LCDD14_0,   NULL);
	gpio_request(GPIO_FN_LCDD13_0,   NULL);
	gpio_request(GPIO_FN_LCDD12_0,   NULL);
	gpio_request(GPIO_FN_LCDD11_0,   NULL);
	gpio_request(GPIO_FN_LCDD10_0,   NULL);
	gpio_request(GPIO_FN_LCDD9_0,    NULL);
	gpio_request(GPIO_FN_LCDD8_0,    NULL);
	gpio_request(GPIO_FN_LCDD7_0,    NULL);
	gpio_request(GPIO_FN_LCDD6_0,    NULL);
	gpio_request(GPIO_FN_LCDD5_0,    NULL);
	gpio_request(GPIO_FN_LCDD4_0,    NULL);
	gpio_request(GPIO_FN_LCDD3_0,    NULL);
	gpio_request(GPIO_FN_LCDD2_0,    NULL);
	gpio_request(GPIO_FN_LCDD1_0,    NULL);
	gpio_request(GPIO_FN_LCDD0_0,    NULL);
	gpio_request(GPIO_FN_LCDDCK_0,   NULL);
	gpio_request(GPIO_FN_LCDVSYN_0,  NULL);
	gpio_request(GPIO_FN_LCDHSYN_0,  NULL);
	gpio_request(GPIO_FN_LCDDISP_0,  NULL);
	gpio_request(GPIO_FN_LCDRD_0,    NULL);
	gpio_request(GPIO_FN_PORT165_LCDLCLK_0,  NULL);
	gpio_request(GPIO_PORT61, NULL); /* LCDDON */
	gpio_direction_output(GPIO_PORT61, 1);
	/* backlight on */
	fpga_write(FPGA_LCDCR, 1, 1);

	/* FSIA */
#ifdef CONFIG_SND_SOC_SH4_FSI_MASTER
	gpio_request(GPIO_FN_FSIAOBT, NULL);
	gpio_request(GPIO_FN_FSIAOLR, NULL);
	gpio_request(GPIO_FN_FSIAOMC, NULL);
	gpio_request(GPIO_FN_FSIACK, NULL);
	gpio_request(GPIO_FN_PORT5_FSIAISLD, NULL);
	gpio_request(GPIO_FN_FSIAOSLD, NULL);
	gpio_request(GPIO_PORT12,  NULL);
	gpio_request(GPIO_PORT13, NULL);
	gpio_no_direction(GPIO_PORT12CR); /* FSIAIBT needs no direction */
	gpio_no_direction(GPIO_PORT13CR); /* FSIAILR needs no direction */
#else
	gpio_request(GPIO_FN_FSIAIBT, NULL);
	gpio_request(GPIO_FN_FSIAILR, NULL);
	gpio_request(GPIO_FN_PORT5_FSIAISLD, NULL);
	gpio_request(GPIO_FN_FSIAOSLD, NULL);
	gpio_request(GPIO_PORT7,  NULL);
	gpio_request(GPIO_PORT8, NULL);
	gpio_no_direction(GPIO_PORT7CR); /* FSIAOBT needs no direction */
	gpio_no_direction(GPIO_PORT8CR); /* FSIAOLR needs no direction */
#endif
	clk_set_parent(fsia_clk, fsiack_clk);
#ifdef CONFIG_SND_SOC_SH4_FSI_MASTER
	clk_enable(fsia_clk);
#endif
	clk_enable(clk_get(NULL, "fsi"));

	/* FMSI */
#ifdef CONFIG_SND_SOC_SH4_FMSI_MASTER
	gpio_request(GPIO_FN_FMSOOLR, NULL);
	gpio_request(GPIO_FN_FMSOOBT, NULL);
#else
	gpio_request(GPIO_FN_FMSIOLR, NULL);
	gpio_request(GPIO_FN_FMSIOBT, NULL);
#endif
	gpio_request(GPIO_FN_FMSOCK, NULL);
	gpio_request(GPIO_FN_PORT6_FMSISLD, NULL);
	gpio_request(GPIO_FN_FMSOSLD, NULL);
	clk_set_parent(fmso_clk, fmsock_clk);
#ifdef CONFIG_SND_SOC_SH4_FMSI_MASTER
	clk_enable(fmso_clk);
#endif
	clk_enable(clk_get(NULL, "fmsi"));

	/* USB */
	gpio_request(GPIO_FN_PPON_0, NULL);
	gpio_request(GPIO_FN_OCI_0, NULL);
	gpio_request(GPIO_FN_PPON_1, NULL);
	gpio_request(GPIO_FN_OCI_1, NULL);
	usb_clk = clk_get(NULL, "usb_clk");
	usbp_clk = clk_get(NULL, "usbp_clk");
	usbh_clk = clk_get(NULL, "usbh");
	usbphy_clk = clk_get(NULL, "usb_phy");
	clk_set_parent(usb_clk, usb24s_div2);
	clk_put(usb24s_div2);

	/* ceu0 */
#if defined(CONFIG_VIDEO_CE150X) || defined(CONFIG_VIDEO_CE150X_MODULE)
	gpio_request(GPIO_FN_PORT24_VIO_D15_0, NULL);
	gpio_request(GPIO_FN_PORT25_VIO_D14_0, NULL);
	gpio_request(GPIO_FN_PORT26_VIO_D13_0, NULL);
	gpio_request(GPIO_FN_VIO_D12_0, NULL);
	gpio_request(GPIO_FN_VIO_D11_0, NULL);
	gpio_request(GPIO_FN_VIO_D10_0, NULL);
	gpio_request(GPIO_FN_VIO_D9_0, NULL);
	gpio_request(GPIO_FN_VIO_D8_0, NULL);
#endif
	gpio_request(GPIO_FN_VIO_D7_0, NULL);
	gpio_request(GPIO_FN_VIO_D6_0, NULL);
	gpio_request(GPIO_FN_VIO_D5_0, NULL);
	gpio_request(GPIO_FN_VIO_D4_0, NULL);
	gpio_request(GPIO_FN_VIO_D3_0, NULL);
	gpio_request(GPIO_FN_VIO_D2_0, NULL);
	gpio_request(GPIO_FN_VIO_D1_0, NULL);
	gpio_request(GPIO_FN_VIO_D0_0, NULL);
	gpio_request(GPIO_FN_VIO_CLK_0, NULL);
	gpio_request(GPIO_FN_VIO_CKO, NULL);
	gpio_request(GPIO_FN_VIO_HD_0, NULL);
	gpio_request(GPIO_FN_VIO_FIELD_0, NULL);
	gpio_request(GPIO_FN_VIO_VD_0, NULL);
	clk = clk_get(NULL, "ceu0");
	if (!IS_ERR(clk)) {
		clk_enable(clk);
		clk_put(clk);
	} else
		printk(KERN_ERR "clk_get(ceu0) failed\n");

	/* FPGA */
	gpio_request(GPIO_FN_CS5B_, NULL);
	gpio_request(GPIO_FN_CS6A_, NULL);
	gpio_request(GPIO_FN_PORT105_CS5A_, NULL);
	gpio_request(GPIO_FN_IRQ10_19, NULL);

#ifdef CONFIG_CACHE_L2X0
	/* Early BRESP enable, Shared attribute override enable, 32K*8way */
	l2x0_init(__io(0xf0100000), 0x40440000, 0x82000fff);
#endif

	i2c_register_board_info(0, i2c0_devices, ARRAY_SIZE(i2c0_devices));
	i2c_register_board_info(1, i2c1_devices, ARRAY_SIZE(i2c1_devices));

	sh7740_add_standard_devices();
	platform_add_devices(rma1evb_devices, ARRAY_SIZE(rma1evb_devices));
}

static void __init rma1evb_timer_init(void)
{
	u16 val;

	val = fpga_read(FPGA_A1MDSR);
	sh7740_clock_init(val & 0x100, val & 0x200, val & 0x400);
	shmobile_timer.init();
}

struct sys_timer rma1evb_timer = {
	.init	= rma1evb_timer_init,
};

MACHINE_START(RMA1EVB, "rma1evb")
	.phys_io	= 0xe8080000,
	.io_pg_offst	= ((0xe8080000) >> 18) & 0xfffc,
	.map_io		= rma1evb_map_io,
	.init_irq	= rma1evb_init_irq,
	.init_machine	= rma1evb_init,
	.timer		= &rma1evb_timer,
MACHINE_END
