/*
 * uPD77660 processor support - PFC hardware block
 *
 * Copyright (C) 2011 Renesas Electronics Corporation
 * Copyright (C) 2010 Renesas Solutions Corp.
 * Copyright (C) 2010 NISHIMOTO Hiroki
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include <linux/init.h>
#include <linux/kernel.h>
#include <linux/gpio.h>
#include <mach/sh7740.h>

#define _1(fn, pfx, sfx) fn(pfx, sfx)

#define _10(fn, pfx, sfx)				\
	_1(fn, pfx##0, sfx), _1(fn, pfx##1, sfx),	\
	_1(fn, pfx##2, sfx), _1(fn, pfx##3, sfx),	\
	_1(fn, pfx##4, sfx), _1(fn, pfx##5, sfx),	\
	_1(fn, pfx##6, sfx), _1(fn, pfx##7, sfx),	\
	_1(fn, pfx##8, sfx), _1(fn, pfx##9, sfx)

#define _211(fn, pfx, sfx)				\
	_10(fn, pfx,    sfx),  _10(fn, pfx##1, sfx),	\
	_10(fn, pfx##2, sfx),  _10(fn, pfx##3, sfx),	\
	_10(fn, pfx##4, sfx),  _10(fn, pfx##5, sfx),	\
	_10(fn, pfx##6, sfx),  _10(fn, pfx##7, sfx),	\
	_10(fn, pfx##8, sfx),  _10(fn, pfx##9, sfx),	\
	_10(fn, pfx##10, sfx), _10(fn, pfx##11, sfx),	\
	_10(fn, pfx##12, sfx), _10(fn, pfx##13, sfx),	\
	_10(fn, pfx##14, sfx), _10(fn, pfx##15, sfx),	\
	_10(fn, pfx##16, sfx), _10(fn, pfx##17, sfx),	\
	_10(fn, pfx##18, sfx), _10(fn, pfx##19, sfx),	\
	_10(fn, pfx##20, sfx), _1(fn, pfx##210, sfx),	\
	_1(fn, pfx##211, sfx)

#define _PORT(pfx, sfx) pfx##_##sfx
#define PORT_ALL(str) _211(_PORT, PORT, str)

enum {
	PINMUX_RESERVED = 0,

	/* PORT0_DATA -> PORT211_DATA */
	PINMUX_DATA_BEGIN,
	PORT_ALL(DATA),
	PINMUX_DATA_END,

	/* PORT0_IN -> PORT211_IN */
	PINMUX_INPUT_BEGIN,
	PORT_ALL(IN),
	PINMUX_INPUT_END,

	/* PORT0_IN_PU -> PORT211_IN_PU */
	PINMUX_INPUT_PULLUP_BEGIN,
	PORT_ALL(IN_PU),
	PINMUX_INPUT_PULLUP_END,

	/* PORT0_IN_PD -> PORT211_IN_PD */
	PINMUX_INPUT_PULLDOWN_BEGIN,
	PORT_ALL(IN_PD),
	PINMUX_INPUT_PULLDOWN_END,

	/* PORT0_OUT -> PORT211_OUT */
	PINMUX_OUTPUT_BEGIN,
	PORT_ALL(OUT),
	PINMUX_OUTPUT_END,

	PINMUX_FUNCTION_BEGIN,
	PORT_ALL(FN_IN),	/* PORT0_FN_IN -> PORT211_FN_IN */
	PORT_ALL(FN_OUT),	/* PORT0_FN_OUT -> PORT211_FN_OUT */
	PORT_ALL(FN0),		/* PORT0_FN0 -> PORT211_FN0 */
	PORT_ALL(FN1),		/* PORT0_FN1 -> PORT211_FN1 */
	PORT_ALL(FN2),		/* PORT0_FN2 -> PORT211_FN2 */
	PORT_ALL(FN3),		/* PORT0_FN3 -> PORT211_FN3 */
	PORT_ALL(FN4),		/* PORT0_FN4 -> PORT211_FN4 */
	PORT_ALL(FN5),		/* PORT0_FN5 -> PORT211_FN5 */
	PORT_ALL(FN6),		/* PORT0_FN6 -> PORT211_FN6 */
	PORT_ALL(FN7),		/* PORT0_FN7 -> PORT211_FN7 */

	MSEL1CR_31_0,	MSEL1CR_31_1,
	MSEL1CR_30_0,	MSEL1CR_30_1,
	MSEL1CR_29_0,	MSEL1CR_29_1,
	MSEL1CR_28_0,	MSEL1CR_28_1,
	MSEL1CR_27_0,	MSEL1CR_27_1,
	MSEL1CR_26_0,	MSEL1CR_26_1,
	MSEL1CR_16_0,	MSEL1CR_16_1,
	MSEL1CR_15_0,	MSEL1CR_15_1,
	MSEL1CR_14_0,	MSEL1CR_14_1,
	MSEL1CR_13_0,	MSEL1CR_13_1,
	MSEL1CR_12_0,	MSEL1CR_12_1,
	MSEL1CR_9_0,	MSEL1CR_9_1,
	MSEL1CR_7_0,	MSEL1CR_7_1,
	MSEL1CR_6_0,	MSEL1CR_6_1,
	MSEL1CR_5_0,	MSEL1CR_5_1,
	MSEL1CR_4_0,	MSEL1CR_4_1,
	MSEL1CR_3_0,	MSEL1CR_3_1,
	MSEL1CR_2_0,	MSEL1CR_2_1,
	MSEL1CR_0_0,	MSEL1CR_0_1,

	MSEL3CR_15_0,	MSEL3CR_15_1,
	MSEL3CR_6_0,	MSEL3CR_6_1,

	MSEL4CR_19_0,	MSEL4CR_19_1,
	MSEL4CR_18_0,	MSEL4CR_18_1,
	MSEL4CR_15_0,	MSEL4CR_15_1,
	MSEL4CR_10_0,	MSEL4CR_10_1,
	MSEL4CR_6_0,	MSEL4CR_6_1,
	MSEL4CR_4_0,	MSEL4CR_4_1,
	MSEL4CR_1_0,	MSEL4CR_1_1,

	MSEL5CR_31_0,	MSEL5CR_31_1,
	MSEL5CR_30_0,	MSEL5CR_30_1,
	MSEL5CR_29_0,	MSEL5CR_29_1,
	MSEL5CR_27_0,	MSEL5CR_27_1,
	MSEL5CR_25_0,	MSEL5CR_25_1,
	MSEL5CR_23_0,	MSEL5CR_23_1,
	MSEL5CR_21_0,	MSEL5CR_21_1,
	MSEL5CR_19_0,	MSEL5CR_19_1,
	MSEL5CR_17_0,	MSEL5CR_17_1,
	MSEL5CR_15_0,	MSEL5CR_15_1,
	MSEL5CR_14_0,	MSEL5CR_14_1,
	MSEL5CR_13_0,	MSEL5CR_13_1,
	MSEL5CR_12_0,	MSEL5CR_12_1,
	MSEL5CR_11_0,	MSEL5CR_11_1,
	MSEL5CR_10_0,	MSEL5CR_10_1,
	MSEL5CR_8_0,	MSEL5CR_8_1,
	MSEL5CR_7_0,	MSEL5CR_7_1,
	MSEL5CR_6_0,	MSEL5CR_6_1,
	MSEL5CR_5_0,	MSEL5CR_5_1,
	MSEL5CR_4_0,	MSEL5CR_4_1,
	MSEL5CR_3_0,	MSEL5CR_3_1,
	MSEL5CR_2_0,	MSEL5CR_2_1,
	MSEL5CR_0_0,	MSEL5CR_0_1,
	PINMUX_FUNCTION_END,

	PINMUX_MARK_BEGIN,
	/* IRQ */
	IRQ0_2_MARK,	IRQ0_13_MARK,	IRQ1_20_MARK,	IRQ2_11_MARK,
	IRQ2_12_MARK,	IRQ3_10_MARK,	IRQ3_14_MARK,	IRQ4_15_MARK,
	IRQ4_172_MARK,	IRQ5_0_MARK,	IRQ5_1_MARK,	IRQ6_121_MARK,
	IRQ6_173_MARK,	IRQ7_120_MARK,	IRQ7_209_MARK,	IRQ8_119_MARK,
	IRQ9_118_MARK,	IRQ9_210_MARK,	IRQ10_19_MARK,	IRQ11_104_MARK,
	IRQ12_42_MARK,	IRQ12_97_MARK,	IRQ13_64_MARK,	IRQ13_98_MARK,
	IRQ14_63_MARK,	IRQ14_99_MARK,	IRQ15_62_MARK,	IRQ15_100_MARK,
	IRQ16_68_MARK,	IRQ16_211_MARK,	IRQ17_69_MARK,	IRQ18_70_MARK,
	IRQ19_71_MARK,	IRQ20_67_MARK,	IRQ21_202_MARK,	IRQ22_95_MARK,
	IRQ23_96_MARK,	IRQ24_180_MARK,	IRQ25_38_MARK,	IRQ26_58_MARK,
	IRQ26_81_MARK,	IRQ27_57_MARK,	IRQ27_168_MARK,	IRQ28_56_MARK,
	IRQ28_169_MARK,	IRQ29_50_MARK,	IRQ29_170_MARK,	IRQ30_49_MARK,
	IRQ30_171_MARK,	IRQ31_41_MARK,	IRQ31_167_MARK,

	/* Function 0-7 */
	DBGMDT2_MARK, PORT0_FSIAISLD_MARK, FSIAOSLD1_MARK, PORT0_LCDD22_0_MARK, SCIFA7_RXD_MARK, LCDD4_1_MARK,
	DBGMDT1_MARK, PORT1_FMSISLD_MARK, FSIAOSLD2_MARK, PORT1_LCDD23_0_MARK, SCIFA7_TXD_MARK, LCDD3_1_MARK,
	DBGMDT0_MARK, PORT2_SCIFB_SCK_MARK, PORT2_LCDD21_0_MARK, LCDD2_1_MARK,
	DBGMD21_MARK, PORT3_SCIFB_RXD_MARK, PORT3_LCDD20_0_MARK, LCDD1_1_MARK,
	DBGMD20_MARK, PORT4_SCIFB_TXD_MARK, PORT4_LCDD19_0_MARK, LCDD0_1_MARK,
	DBGMD11_MARK, PORT5_BBIF2_TXD1_MARK, PORT5_FSIAISLD_MARK, RSPI_SSL0_A_MARK, LCDVCPWC_1_MARK,
	DBGMD10_MARK, PORT6_BBIF2_TSYNC1_MARK, PORT6_FMSISLD_MARK, RSPI_SSL1_A_MARK, LCDVEPWC_1_MARK,
	FSIAOLR_MARK,
	FSIAOBT_MARK,
	FSIAOSLD_MARK, PORT9_FSIASPDIF_MARK,

	FSIAOMC_MARK, PORT10_SCIFA5_RXD_MARK,
	FSIACK_MARK,
	FSIAILR_MARK, PORT12_SCIFA4_RXD_MARK, LCDRS_1_MARK, LCDDISP_1_MARK,
	FSIAIBT_MARK, PORT13_SCIFA4_TXD_MARK, LCDRD_1_MARK,
	FMSOILR_MARK, FMSIILR_MARK, VIO_CKO1_MARK, LCDD23_1_MARK,
	FMSOIBT_MARK, FMSIIBT_MARK, VIO_CKO2_MARK, LCDD22_1_MARK,
	FMSOOLR_MARK, FMSIOLR_MARK,
	FMSOOBT_MARK, FMSIOBT_MARK,
	FMSOSLD_MARK, PORT18_FSIASPDIF_MARK,
	FMSICK_MARK, PORT19_CS5A__MARK,

	FMSOCK_MARK, PORT20_SCIFA5_TXD_MARK,
	SCIFA1_CTS__MARK, PORT21_SCIFA4_SCK_MARK, TPU0TO1_MARK, VIO_FIELD_1_MARK, STP_IPD5_0_MARK, LCDD10_1_MARK,
	PORT22_SCIFA2_SCK_MARK, PORT22_SIM_D_MARK, PORT22_VIO_D13_0_MARK,
	SCIFA1_RTS__MARK, PORT23_SCIFA5_SCK_MARK, TPU0TO0_MARK, VIO_CKO_1_MARK, STP_IPD2_0_MARK, LCDD7_1_MARK,
	PORT24_VIO_D15_0_MARK, VIO_D7_1_MARK, SCIFA6_SCK_MARK, PORT24_SDHICD2_MARK,
	PORT25_VIO_D14_0_MARK, VIO_D6_1_MARK, SCIFA6_RXD_MARK, PORT25_SDHIWP2_MARK,
	PORT26_VIO_D13_0_MARK, VIO_D5_1_MARK, SCIFA6_TXD_MARK,
	VIO_D7_0_MARK,
	VIO_D6_0_MARK,
	VIO_D5_0_MARK,

	VIO_D4_0_MARK,
	VIO_D3_0_MARK,
	VIO_D2_0_MARK,
	VIO_D1_0_MARK,
	VIO_D0_0_MARK,
	VIO_CLK_0_MARK,
	VIO_CKO_MARK,
	VIO_HD_0_MARK,
	VIO_FIELD_0_MARK,
	VIO_VD_0_MARK,

	PORT40_LCDD18_0_MARK, RSPI_CK_A_MARK, LCDLCLK_1_MARK,
	LCDD17_0_MARK, MSIOF2_SS1_MARK,
	LCDD16_0_MARK, MSIOF2_MCK1_MARK,
	LCDD15_0_MARK, MSIOF2_MCK0_MARK, PORT43_KEYIN0_MARK, DV_D15_MARK,
	LCDD14_0_MARK, MSIOF2_RSYNC_MARK, PORT44_KEYIN1_MARK, DV_D14_MARK,
	LCDD13_0_MARK, MSIOF2_RSCK_MARK, PORT45_KEYIN2_MARK, DV_D13_MARK,
	LCDD12_0_MARK, PORT46_KEYIN3_MARK, DV_D12_MARK,
	LCDD11_0_MARK, KEYIN4_MARK, DV_D11_MARK,
	LCDD10_0_MARK, KEYIN5_MARK, DV_D10_MARK,
	LCDD9_0_MARK, KEYIN6_MARK, DV_D9_MARK,

	LCDD8_0_MARK, KEYIN7_MARK, DV_D8_MARK,
	LCDD7_0_MARK, KEYOUT0_MARK, DV_D7_MARK,
	LCDD6_0_MARK, KEYOUT1_MARK, DV_D6_MARK,
	LCDD5_0_MARK, KEYOUT2_MARK, DV_D5_MARK,
	LCDD4_0_MARK, KEYOUT3_MARK, DV_D4_MARK,
	LCDD3_0_MARK, KEYOUT4_MARK, PORT55_KEYIN3_MARK, DV_D3_MARK,
	LCDD2_0_MARK, KEYOUT5_MARK, PORT56_KEYIN2_MARK, DV_D2_MARK,
	LCDD1_0_MARK, KEYOUT6_MARK, PORT57_KEYIN1_MARK, DV_D1_MARK,
	LCDD0_0_MARK, KEYOUT7_MARK, PORT58_KEYIN0_MARK, DV_D0_MARK,
	LCDVCPWC_0_MARK, PORT59_BBIF2_TSCK1_MARK, RSPI_MOSI_A_MARK,

	LCDVEPWC_0_MARK, PORT60_BBIF2_RXD_MARK, RSPI_MISO_A_MARK,
	LCDDON_0_MARK, MSIOF2_TXD_MARK,
	LCDDCK_0_MARK, LCDWR_0_MARK, DV_CLK_MARK,
	LCDVSYN_0_MARK, DV_VSYNC_MARK,
	LCDHSYN_0_MARK, LCDCS_0_MARK, DV_HSYNC_MARK,
	LCDDISP_0_MARK, MSIOF2_TSCK_MARK, LCDRS_0_MARK,
	MEMC_INT_MARK, PORT66_TPU0TO2_MARK, PORT66_MMCCLK0_MARK, SDHICLK1_MARK,
	MEMC_CS0_MARK, PORT67_MSIOF1_SS1_MARK, PORT67_MMCCMD0_MARK, SDHICMD1_MARK,
	MEMC_AD8_MARK, MSIOF1_RSCK_MARK, PORT68_MMCD0_0_MARK, SDHID1_0_MARK,
	MEMC_AD9_MARK, MSIOF1_RSYNC_MARK, PORT69_MMCD0_1_MARK, SDHID1_1_MARK,

	MEMC_AD10_MARK, MSIOF1_MCK0_MARK, PORT70_MMCD0_2_MARK, SDHID1_2_MARK,
	MEMC_AD11_MARK, MSIOF1_MCK1_MARK, PORT71_MMCD0_3_MARK, SDHID1_3_MARK,
	MEMC_AD12_MARK, PORT72_MSIOF1_TSCK_MARK, PORT72_MMCD0_4_MARK, SDHICD1_MARK,
	MEMC_AD13_MARK, PORT73_MSIOF1_TSYNC_MARK, PORT73_MMCD0_5_MARK, SDHIWP1_MARK,
	MEMC_AD14_MARK, PORT74_MSIOF1_TXD_MARK, PORT74_MMCD0_6_MARK, STP_IPD7_1_MARK, LCDD21_1_MARK,
	MEMC_AD15_MARK, PORT75_MSIOF1_RXD_MARK, PORT75_MMCD0_7_MARK, STP_IPD6_1_MARK, LCDD20_1_MARK,
	SDHICMD0_MARK,
	SDHID0_0_MARK,
	SDHID0_1_MARK,
	SDHID0_2_MARK,

	SDHID0_3_MARK,
	SDHICD0_MARK,
	SDHICLK0_MARK,
	SDHIWP0_MARK,
	RESETOUTS__MARK,
	PPON_0_MARK,
	OCI_0_MARK,
	PPON_1_MARK,
	OCI_1_MARK,
	DREQ0_MARK, PORT89_BBIF2_TSCK1_MARK, RSPI_SSL3_A_MARK,

	DACK0_MARK, PORT90_BBIF2_RXD_MARK, RSPI_SSL2_A_MARK, PORT90_WAIT__MARK,
	MEMC_AD0_MARK, BBIF1_RXD_MARK, PORT91_SCIFA5_TXD_MARK, LCDD5_1_MARK,
	MEMC_AD1_MARK, BBIF1_TSYNC_MARK, PORT92_SCIFA5_RXD_MARK, STP_IPD1_0_MARK, LCDD6_1_MARK,
	MEMC_AD2_MARK, BBIF1_TSCK_MARK, PORT93_SCIFA4_TXD_MARK, STP_IPD3_0_MARK, LCDD8_1_MARK,
	MEMC_AD3_MARK, BBIF1_TXD_MARK, PORT94_SCIFA4_RXD_MARK, STP_IPD4_0_MARK, LCDD9_1_MARK,
	MEMC_CS1_MEMC_A1_MARK, SCIFA2_CTS__MARK, STM_RST_MARK, PORT95_VIO_D14_0_MARK,
	MEMC_ADV_MEMC_DREQ0_MARK, SCIFA2_RTS__MARK, STM_CLK_MARK, PORT96_VIO_D15_0_MARK,
	MEMC_AD4_MARK, BBIF1_RSCK_MARK, LCDCS_1_MARK, LCDHSYN_1_MARK,
	MEMC_AD5_MARK, BBIF1_RSYNC_MARK, LCDVSYN_1_MARK,
	MEMC_AD6_MARK, BBIF1_FLOW_MARK, LCDWR_1_MARK, LCDDCK_1_MARK,

	MEMC_AD7_MARK, BB_RX_FLOW_N_MARK, LCDDON_1_MARK,
	FCE0__MARK,
	FRB_MARK, PORT102_LCDLCLK_0_MARK,
	CS5B__MARK, FCE1__MARK, PORT103_MMCCLK0_MARK,
	CS6A__MARK, PORT104_MMCCMD0_MARK,
	PORT105_CS5A__MARK, PORT105_SCIFA3_RTS__MARK,
	IOIS16__MARK, EXBUF_ENB__MARK,
	WE3__MARK,
	WE2__MARK,
	CS0__MARK,

	CS2__MARK,
	CS4__MARK,
	WE1__MARK,
	WE0_FWE_MARK,
	RDWR_MARK,
	RD_FSC_MARK,
	A25_MARK, MSIOF0_SS2_MARK, PORT116_MSIOF1_SS2_MARK, PORT116_SCIFA3_SCK_MARK,
	A24_MARK, MSIOF0_SS1_MARK, PORT117_MSIOF1_SS1_MARK, PORT117_SCIFA3_CTS__MARK,
	A23_MARK, MSIOF0_MCK1_MARK, PORT118_MSIOF1_RXD_MARK,
	A22_MARK, MSIOF0_MCK0_MARK, PORT119_MSIOF1_TXD_MARK,

	A21_MARK, MSIOF0_RSYNC_MARK, PORT120_MSIOF1_TSYNC_MARK,
	A20_MARK, MSIOF0_RSCK_MARK, PORT121_MSIOF1_TSCK_MARK,
	A19_MARK, MSIOF0_RXD_MARK,
	A18_MARK, MSIOF0_TSCK_MARK,
	A17_MARK, MSIOF0_TSYNC_MARK,
	A16_MARK,
	A15_MARK,
	A14_MARK,
	A13_MARK,
	A12_MARK,

	A11_MARK,
	A10_MARK,
	A9_MARK,
	A8_MARK,
	A7_MARK,
	A6_MARK,
	A5_FCDE_MARK,
	A4_FOE_MARK,
	A3_MARK,
	A2_MARK,

	A1_MARK,
	CKO_MARK,
	D15_MARK, PORT142_MMCD0_7_MARK,
	D14_MARK, PORT143_MMCD0_6_MARK,
	D13_MARK, PORT144_MMCD0_5_MARK,
	D12_MARK, PORT145_MMCD0_4_MARK,
	D11_MARK, PORT146_MMCD0_3_MARK,
	D10_MARK, PORT147_MMCD0_2_MARK,
	D9_MARK, PORT148_MMCD0_1_MARK,
	D8_MARK, PORT149_MMCD0_0_MARK,

	D7_MARK,
	D6_MARK,
	D5_MARK,
	D4_MARK,
	D3_MARK,
	D2_MARK,
	D1_MARK,
	D0_MARK,
	D31_MARK, PORT158_SCIFA3_SCK_MARK, REF125CK_MARK, PORT158_LCDD21_0_MARK, IRDA_FIRSEL_MARK, IDED15_MARK,
	D30_MARK, PORT159_SCIFA3_RXD_MARK, REF50CK_MARK, PORT159_LCDD23_0_MARK, IDED14_MARK,

	D29_MARK, PORT160_SCIFA3_TXD_MARK, PORT160_LCDD22_0_MARK, VIO_HD_1_MARK, IDED13_MARK,
	D28_MARK, PORT161_SCIFA3_RTS__MARK, ET_RX_DV_MARK, PORT161_LCDD20_0_MARK, IRDA_IN_MARK, IDED12_MARK,
	D27_MARK, PORT162_SCIFA3_CTS__MARK, PORT162_LCDD19_0_MARK, IRDA_OUT_MARK, IDED11_MARK,
	D26_MARK, MSIOF2_SS2_MARK, ET_COL_MARK, PORT163_LCDD18_0_MARK, IROUT_MARK, IDED10_MARK,
	D25_MARK, MSIOF2_TSYNC_MARK, ET_PHY_INT_MARK, LCDRD_0_MARK, IDED9_MARK,
	D24_MARK, MSIOF2_RXD_MARK, PORT165_LCDLCLK_0_MARK, IDED8_MARK,
	D21_MARK, ET_ETXD5_MARK, IDED5_MARK,
	D20_MARK, ET_ETXD4_MARK, IDED4_MARK,
	D19_MARK, ET_ETXD3_MARK, IDED3_MARK,
	D18_MARK, ET_ETXD2_MARK, IDED2_MARK,

	D17_MARK, ET_ETXD1_MARK, IDED1_MARK,
	D16_MARK, ET_ETXD0_MARK, IDED0_MARK,
	D23_MARK, PORT172_SCIFB_RTS__MARK, ET_ETXD7_MARK, IDED7_MARK,
	D22_MARK, PORT173_SCIFB_CTS__MARK, ET_ETXD6_MARK, IDED6_MARK,
	A26_MARK, MSIOF0_TXD_MARK, ET_RX_CLK_MARK, PORT174_SCIFA3_RXD_MARK,
	A0_MARK, BS_MARK, ET_MAGIC_MARK, PORT175_SCIFA3_TXD_MARK,
	ET_GTX_CLK_MARK,
	PORT177_WAIT__MARK, ET_LINK_MARK, IDEIOWR__MARK, PORT177_SDHIWP2_MARK,
	VIO_D12_0_MARK, VIO_D4_1_MARK, IDEIORD__MARK,
	VIO_D11_0_MARK, VIO_D3_1_MARK, IDEIORDY_MARK,

	VIO_D10_0_MARK, TPU0TO3_MARK, VIO_D2_1_MARK, IDEINT_MARK,
	VIO_D9_0_MARK, VIO_D1_1_MARK, IDERST__MARK,
	VIO_D8_0_MARK, VIO_D0_1_MARK, DIRECTION_MARK,
	DREQ1_MARK, PORT183_BBIF2_TXD1_MARK, ET_TX_EN_MARK,
	DACK1_MARK, PORT184_BBIF2_TSYNC1_MARK, ET_TX_CLK_MARK,
	SCIFA1_SCK_MARK, ET_ERXD0_MARK, STP_IPCLK_1_MARK,
	PORT186_SCIFB_RTS__MARK, ET_ERXD1_MARK, PORT186_STP_IPD0_1_MARK,
	PORT187_SCIFB_CTS__MARK, ET_ERXD2_MARK, PORT187_STP_IPEN_1_MARK,
	SCIFA0_SCK_MARK, ET_ERXD3_MARK, STP_IPSYNC_1_MARK,
	ET_ERXD4_MARK, STP_IPCLK_0_MARK,

	PORT190_SCIFB_SCK_MARK, ET_ERXD5_MARK, STP_IPD0_0_MARK,
	PORT191_SCIFB_RXD_MARK, ET_ERXD6_MARK, STP_IPEN_0_MARK,
	PORT192_SCIFB_TXD_MARK, ET_ERXD7_MARK, STP_IPSYNC_0_MARK,
	SCIFA0_CTS__MARK, RMII_CRS_DV_MARK, PORT193_STP_IPEN_1_MARK, LCDD17_1_MARK,
	SCIFA0_RTS__MARK, RMII_RX_ER_MARK, PORT194_STP_IPD0_1_MARK, LCDD16_1_MARK,
	SCIFA1_RXD_MARK, RMII_RXD0_MARK, STP_IPD3_1_MARK, LCDD15_1_MARK,
	SCIFA1_TXD_MARK, RMII_RXD1_MARK, STP_IPD2_1_MARK, LCDD14_1_MARK,
	SCIFA0_RXD_MARK, VIO_CLK_1_MARK, STP_IPD5_1_MARK, LCDD19_1_MARK,
	SCIFA0_TXD_MARK, VIO_VD_1_MARK, STP_IPD4_1_MARK, LCDD18_1_MARK,
	MEMC_NWE_MARK, PORT199_SCIFA2_SCK_MARK, RMII_TX_EN_MARK, PORT199_SIM_D_MARK, STP_IPD1_1_MARK, LCDD13_1_MARK,

	MEMC_NOE_MARK, SCIFA2_RXD_MARK, RMII_TXD0_MARK, STP_IPD7_0_MARK, LCDD12_1_MARK,
	MEMC_WAIT_MEMC_DREQ1_MARK, SCIFA2_TXD_MARK, RMII_TXD1_MARK, STP_IPD6_0_MARK, LCDD11_1_MARK,
	MEME_BUSCLK_MEMC_A0_MARK, PORT202_MSIOF1_SS2_MARK, RMII_MDC_MARK, PORT202_TPU0TO2_MARK, IDECS0__MARK, PORT202_SDHICD2_MARK,
	SDHICLK2_MARK, ET_TX_ER_MARK, IDEA2_MARK, PORT203_SCIFA4_TXD_MARK,
	SDHICMD2_MARK, ET_RX_ER_MARK, IDEA1_MARK, PORT204_SCIFA4_RXD_MARK,
	SDHID2_0_MARK, ET_CRS_MARK, IDEA0_MARK, PORT205_SCIFA4_SCK_MARK,
	SDHID2_1_MARK, ET_MDC_MARK, IODACK__MARK, PORT206_SCIFA5_SCK_MARK,
	SDHID2_2_MARK, ET_MDIO_MARK, IODREQ_MARK, PORT207_SCIFA5_RXD_MARK,
	SDHID2_3_MARK, RMII_MDIO_MARK, IDECS1__MARK, PORT208_SCIFA5_TXD_MARK,
	VBUS_MARK,

	PINMUX_MARK_END,
};

#define PORT_DATA_I(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, PORT##nr##_IN)

#define PORT_DATA_I_PD(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_IN, PORT##nr##_IN_PD)

#define PORT_DATA_I_PU(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_IN, PORT##nr##_IN_PU)

#define PORT_DATA_I_PU_PD(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_IN, PORT##nr##_IN_PD, PORT##nr##_IN_PU)

#define PORT_DATA_O(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, PORT##nr##_OUT)

#define PORT_DATA_IO(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_OUT, PORT##nr##_IN)

#define PORT_DATA_IO_PD(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_OUT, PORT##nr##_IN, PORT##nr##_IN_PD)

#define PORT_DATA_IO_PU(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
		PORT##nr##_OUT, PORT##nr##_IN, PORT##nr##_IN_PU)

#define PORT_DATA_IO_PU_PD(nr) \
	PINMUX_DATA(PORT##nr##_DATA, PORT##nr##_FN0, \
	  PORT##nr##_OUT, PORT##nr##_IN, PORT##nr##_IN_PD, PORT##nr##_IN_PU)

static pinmux_enum_t pinmux_data[] = {
	/* specify valid pin states for each pin in GPIO mode */

	/* Table 25-1 (I/O and Pull U/D) */
	PORT_DATA_IO_PD(0),	PORT_DATA_IO_PD(1),
	PORT_DATA_IO_PD(2),	PORT_DATA_IO_PD(3),
	PORT_DATA_IO_PD(4),	PORT_DATA_IO_PD(5),
	PORT_DATA_IO_PD(6),	PORT_DATA_IO(7),
	PORT_DATA_IO(8),	PORT_DATA_IO(9),
	PORT_DATA_IO_PD(10),	PORT_DATA_IO_PD(11),
	PORT_DATA_IO_PD(12),	PORT_DATA_IO_PU_PD(13),
	PORT_DATA_IO_PD(14),	PORT_DATA_IO_PD(15),
	PORT_DATA_IO_PD(16),	PORT_DATA_IO_PD(17),
	PORT_DATA_IO(18),	PORT_DATA_IO_PU(19),
	PORT_DATA_IO_PU_PD(20),	PORT_DATA_IO_PD(21),
	PORT_DATA_IO_PU_PD(22),	PORT_DATA_IO(23),
	PORT_DATA_IO_PU(24),	PORT_DATA_IO_PU(25),
	PORT_DATA_IO_PU(26),	PORT_DATA_IO_PU(27),
	PORT_DATA_IO_PU(28),	PORT_DATA_IO_PU(29),
	PORT_DATA_IO_PU(30),	PORT_DATA_IO_PD(31),
	PORT_DATA_IO_PD(32),	PORT_DATA_IO_PD(33),
	PORT_DATA_IO_PD(34),	PORT_DATA_IO_PU(35),
	PORT_DATA_IO_PU(36),	PORT_DATA_IO_PD(37),
	PORT_DATA_IO_PU(38),	PORT_DATA_IO_PD(39),
	PORT_DATA_IO_PU_PD(40),	PORT_DATA_IO_PD(41),
	PORT_DATA_IO_PD(42),	PORT_DATA_IO_PU_PD(43),
	PORT_DATA_IO_PU_PD(44),	PORT_DATA_IO_PU_PD(45),
	PORT_DATA_IO_PU_PD(46),	PORT_DATA_IO_PU_PD(47),
	PORT_DATA_IO_PU_PD(48),	PORT_DATA_IO_PU_PD(49),
	PORT_DATA_IO_PU_PD(50),	PORT_DATA_IO_PD(51),
	PORT_DATA_IO_PD(52),	PORT_DATA_IO_PD(53),
	PORT_DATA_IO_PD(54),	PORT_DATA_IO_PU_PD(55),
	PORT_DATA_IO_PU_PD(56),	PORT_DATA_IO_PU_PD(57),
	PORT_DATA_IO_PU_PD(58),	PORT_DATA_IO_PU_PD(59),
	PORT_DATA_IO_PU_PD(60),	PORT_DATA_IO_PD(61),
	PORT_DATA_IO_PD(62),	PORT_DATA_IO_PD(63),
	PORT_DATA_IO_PD(64),	PORT_DATA_IO_PD(65),
	PORT_DATA_IO_PU_PD(66),	PORT_DATA_IO_PU_PD(67),
	PORT_DATA_IO_PU_PD(68),	PORT_DATA_IO_PU_PD(69),
	PORT_DATA_IO_PU_PD(70),	PORT_DATA_IO_PU_PD(71),
	PORT_DATA_IO_PU_PD(72),	PORT_DATA_IO_PU_PD(73),
	PORT_DATA_IO_PU_PD(74),	PORT_DATA_IO_PU_PD(75),
	PORT_DATA_IO_PU_PD(76),	PORT_DATA_IO_PU_PD(77),
	PORT_DATA_IO_PU_PD(78),	PORT_DATA_IO_PU_PD(79),
	PORT_DATA_IO_PU_PD(80),	PORT_DATA_IO_PU_PD(81),
	PORT_DATA_IO(82),	PORT_DATA_IO_PU_PD(83),
	PORT_DATA_IO(84),	PORT_DATA_IO_PD(85),
	PORT_DATA_IO_PD(86),	PORT_DATA_IO_PD(87),
	PORT_DATA_IO_PD(88),	PORT_DATA_IO_PD(89),
	PORT_DATA_IO_PD(90),	PORT_DATA_IO_PU_PD(91),
	PORT_DATA_IO_PU_PD(92),	PORT_DATA_IO_PU_PD(93),
	PORT_DATA_IO_PU_PD(94),	PORT_DATA_IO_PU_PD(95),
	PORT_DATA_IO_PU_PD(96),	PORT_DATA_IO_PU_PD(97),
	PORT_DATA_IO_PU_PD(98),	PORT_DATA_IO_PU_PD(99),
	PORT_DATA_IO_PU_PD(100),PORT_DATA_IO(101),
	PORT_DATA_IO_PU(102),	PORT_DATA_IO_PU_PD(103),
	PORT_DATA_IO_PU(104),	PORT_DATA_IO_PU(105),
	PORT_DATA_IO_PU_PD(106),PORT_DATA_IO(107),
	PORT_DATA_IO(108),	PORT_DATA_IO(109),
	PORT_DATA_IO(110),	PORT_DATA_IO(111),
	PORT_DATA_IO(112),	PORT_DATA_IO(113),
	PORT_DATA_IO_PU_PD(114),PORT_DATA_IO(115),
	PORT_DATA_IO_PD(116),	PORT_DATA_IO_PD(117),
	PORT_DATA_IO_PD(118),	PORT_DATA_IO_PD(119),
	PORT_DATA_IO_PD(120),	PORT_DATA_IO_PD(121),
	PORT_DATA_IO_PD(122),	PORT_DATA_IO_PD(123),
	PORT_DATA_IO_PD(124),	PORT_DATA_IO(125),
	PORT_DATA_IO(126),	PORT_DATA_IO(127),
	PORT_DATA_IO(128),	PORT_DATA_IO(129),
	PORT_DATA_IO(130),	PORT_DATA_IO(131),
	PORT_DATA_IO(132),	PORT_DATA_IO(133),
	PORT_DATA_IO(134),	PORT_DATA_IO(135),
	PORT_DATA_IO(136),	PORT_DATA_IO(137),
	PORT_DATA_IO(138),	PORT_DATA_IO(139),
	PORT_DATA_IO(140),	PORT_DATA_IO(141),
	PORT_DATA_IO_PU(142),	PORT_DATA_IO_PU(143),
	PORT_DATA_IO_PU(144),	PORT_DATA_IO_PU(145),
	PORT_DATA_IO_PU(146),	PORT_DATA_IO_PU(147),
	PORT_DATA_IO_PU(148),	PORT_DATA_IO_PU(149),
	PORT_DATA_IO_PU(150),	PORT_DATA_IO_PU(151),
	PORT_DATA_IO_PU(152),	PORT_DATA_IO_PU(153),
	PORT_DATA_IO_PU(154),	PORT_DATA_IO_PU(155),
	PORT_DATA_IO_PU(156),	PORT_DATA_IO_PU(157),
	PORT_DATA_IO_PD(158),	PORT_DATA_IO_PD(159),
	PORT_DATA_IO_PU_PD(160),PORT_DATA_IO_PD(161),
	PORT_DATA_IO_PD(162),	PORT_DATA_IO_PD(163),
	PORT_DATA_IO_PD(164),	PORT_DATA_IO_PD(165),
	PORT_DATA_IO_PU(166),	PORT_DATA_IO_PU(167),
	PORT_DATA_IO_PU(168),	PORT_DATA_IO_PU(169),
	PORT_DATA_IO_PU(170),	PORT_DATA_IO_PU(171),
	PORT_DATA_IO_PD(172),	PORT_DATA_IO_PD(173),
	PORT_DATA_IO_PD(174),	PORT_DATA_IO_PD(175),
	PORT_DATA_IO_PU(176),	PORT_DATA_IO_PU_PD(177),
	PORT_DATA_IO_PU(178),	PORT_DATA_IO_PD(179),
	PORT_DATA_IO_PD(180),	PORT_DATA_IO_PU(181),
	PORT_DATA_IO_PU(182),	PORT_DATA_IO(183),
	PORT_DATA_IO_PD(184),	PORT_DATA_IO_PD(185),
	PORT_DATA_IO_PD(186),	PORT_DATA_IO_PD(187),
	PORT_DATA_IO_PD(188),	PORT_DATA_IO_PD(189),
	PORT_DATA_IO_PD(190),	PORT_DATA_IO_PD(191),
	PORT_DATA_IO_PD(192),	PORT_DATA_IO_PU_PD(193),
	PORT_DATA_IO_PU_PD(194),PORT_DATA_IO_PD(195),
	PORT_DATA_IO_PU_PD(196),PORT_DATA_IO_PD(197),
	PORT_DATA_IO_PU_PD(198),PORT_DATA_IO_PU_PD(199),
	PORT_DATA_IO_PU_PD(200),PORT_DATA_IO_PU(201),
	PORT_DATA_IO_PU_PD(202),PORT_DATA_IO(203),
	PORT_DATA_IO_PU_PD(204),PORT_DATA_IO_PU_PD(205),
	PORT_DATA_IO_PU_PD(206),PORT_DATA_IO_PU_PD(207),
	PORT_DATA_IO_PU_PD(208),PORT_DATA_IO_PD(209),
	PORT_DATA_IO_PD(210),	PORT_DATA_I_PD(211),

	/* IRQ */
	PINMUX_DATA(IRQ0_2_MARK,	PORT2_FN0,	MSEL1CR_0_1),
	PINMUX_DATA(IRQ0_13_MARK,	PORT13_FN0,	MSEL1CR_0_0),
	PINMUX_DATA(IRQ1_20_MARK,	PORT20_FN0),
	PINMUX_DATA(IRQ2_11_MARK,	PORT22_FN0,	MSEL1CR_2_0),
	PINMUX_DATA(IRQ2_12_MARK,	PORT12_FN0,	MSEL1CR_2_1),
	PINMUX_DATA(IRQ3_10_MARK,	PORT10_FN0,	MSEL1CR_3_0),
	PINMUX_DATA(IRQ3_14_MARK,	PORT14_FN0,	MSEL1CR_3_1),
	PINMUX_DATA(IRQ4_15_MARK,	PORT15_FN0,	MSEL1CR_4_0),
	PINMUX_DATA(IRQ4_172_MARK,	PORT172_FN0,	MSEL1CR_4_1),
	PINMUX_DATA(IRQ5_0_MARK,	PORT0_FN0,	MSEL1CR_5_0),
	PINMUX_DATA(IRQ5_1_MARK,	PORT1_FN0,	MSEL1CR_5_1),
	PINMUX_DATA(IRQ6_121_MARK,	PORT121_FN0,	MSEL1CR_6_0),
	PINMUX_DATA(IRQ6_173_MARK,	PORT173_FN0,	MSEL1CR_6_1),
	PINMUX_DATA(IRQ7_120_MARK,	PORT120_FN0,	MSEL1CR_7_1),
	PINMUX_DATA(IRQ7_209_MARK,	PORT209_FN0,	MSEL1CR_7_0),
	PINMUX_DATA(IRQ8_119_MARK,	PORT119_FN0),
	PINMUX_DATA(IRQ9_118_MARK,	PORT118_FN0,	MSEL1CR_9_0),
	PINMUX_DATA(IRQ9_210_MARK,	PORT210_FN0,	MSEL1CR_9_1),
	PINMUX_DATA(IRQ10_19_MARK,	PORT19_FN0),
	PINMUX_DATA(IRQ11_104_MARK,	PORT104_FN0),
	PINMUX_DATA(IRQ12_42_MARK,	PORT42_FN0,	MSEL1CR_12_1),
	PINMUX_DATA(IRQ12_97_MARK,	PORT97_FN0,	MSEL1CR_12_0),
	PINMUX_DATA(IRQ13_64_MARK,	PORT64_FN0,	MSEL1CR_13_1),
	PINMUX_DATA(IRQ13_98_MARK,	PORT98_FN0,	MSEL1CR_13_0),
	PINMUX_DATA(IRQ14_63_MARK,	PORT63_FN0,	MSEL1CR_14_1),
	PINMUX_DATA(IRQ14_99_MARK,	PORT99_FN0,	MSEL1CR_14_0),
	PINMUX_DATA(IRQ15_62_MARK,	PORT62_FN0,	MSEL1CR_15_1),
	PINMUX_DATA(IRQ15_100_MARK,	PORT100_FN0,	MSEL1CR_15_0),
	PINMUX_DATA(IRQ16_68_MARK,	PORT68_FN0,	MSEL1CR_16_0),
	PINMUX_DATA(IRQ16_211_MARK,	PORT211_FN0,	MSEL1CR_16_1),
	PINMUX_DATA(IRQ17_69_MARK,	PORT69_FN0),
	PINMUX_DATA(IRQ18_70_MARK,	PORT70_FN0),
	PINMUX_DATA(IRQ19_71_MARK,	PORT71_FN0),
	PINMUX_DATA(IRQ20_67_MARK,	PORT67_FN0),
	PINMUX_DATA(IRQ21_202_MARK,	PORT202_FN0),
	PINMUX_DATA(IRQ22_95_MARK,	PORT95_FN0),
	PINMUX_DATA(IRQ23_96_MARK,	PORT96_FN0),
	PINMUX_DATA(IRQ24_180_MARK,	PORT180_FN0),
	PINMUX_DATA(IRQ25_38_MARK,	PORT38_FN0),
	PINMUX_DATA(IRQ26_58_MARK,	PORT58_FN0,	MSEL1CR_26_1),
	PINMUX_DATA(IRQ26_81_MARK,	PORT81_FN0,	MSEL1CR_26_0),
	PINMUX_DATA(IRQ27_57_MARK,	PORT57_FN0,	MSEL1CR_27_1),
	PINMUX_DATA(IRQ27_168_MARK,	PORT168_FN0,	MSEL1CR_27_0),
	PINMUX_DATA(IRQ28_56_MARK,	PORT56_FN0,	MSEL1CR_28_1),
	PINMUX_DATA(IRQ28_169_MARK,	PORT169_FN0,	MSEL1CR_28_0),
	PINMUX_DATA(IRQ29_50_MARK,	PORT50_FN0,	MSEL1CR_29_1),
	PINMUX_DATA(IRQ29_170_MARK,	PORT170_FN0,	MSEL1CR_29_0),
	PINMUX_DATA(IRQ30_49_MARK,	PORT49_FN0,	MSEL1CR_30_1),
	PINMUX_DATA(IRQ30_171_MARK,	PORT171_FN0,	MSEL1CR_30_0),
	PINMUX_DATA(IRQ31_41_MARK,	PORT41_FN0,	MSEL1CR_31_1),
	PINMUX_DATA(IRQ31_167_MARK,	PORT167_FN0,	MSEL1CR_31_0),

	/* Function 0-7 */
	PINMUX_DATA(DBGMDT2_MARK, PORT0_FN1), \
		PINMUX_DATA(PORT0_FSIAISLD_MARK, PORT0_FN2, PORT0_IN_PU, MSEL5CR_3_0), \
		PINMUX_DATA(FSIAOSLD1_MARK, PORT0_FN3), \
		PINMUX_DATA(PORT0_LCDD22_0_MARK, PORT0_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(SCIFA7_RXD_MARK, PORT0_FN6), \
		PINMUX_DATA(LCDD4_1_MARK, PORT0_FN7),
	PINMUX_DATA(DBGMDT1_MARK, PORT1_FN1), \
		PINMUX_DATA(PORT1_FMSISLD_MARK, PORT1_FN2, MSEL5CR_5_0), \
		PINMUX_DATA(FSIAOSLD2_MARK, PORT1_FN3), \
		PINMUX_DATA(PORT1_LCDD23_0_MARK, PORT1_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(SCIFA7_TXD_MARK, PORT1_FN6), \
		PINMUX_DATA(LCDD3_1_MARK, PORT1_FN7),
	PINMUX_DATA(DBGMDT0_MARK, PORT2_FN1), \
		PINMUX_DATA(PORT2_SCIFB_SCK_MARK, PORT2_FN2, MSEL5CR_17_1), \
		PINMUX_DATA(PORT2_LCDD21_0_MARK, PORT2_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(LCDD2_1_MARK, PORT2_FN7),
	PINMUX_DATA(DBGMD21_MARK, PORT3_FN1), \
		PINMUX_DATA(PORT3_SCIFB_RXD_MARK, PORT3_FN2, MSEL5CR_17_1), \
		PINMUX_DATA(PORT3_LCDD20_0_MARK, PORT3_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(LCDD1_1_MARK, PORT3_FN7),
	PINMUX_DATA(DBGMD20_MARK, PORT4_FN1), \
		PINMUX_DATA(PORT4_SCIFB_TXD_MARK, PORT4_FN2, MSEL5CR_17_1), \
		PINMUX_DATA(PORT4_LCDD19_0_MARK, PORT4_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(LCDD0_1_MARK, PORT4_FN7),
	PINMUX_DATA(DBGMD11_MARK, PORT5_FN1), \
		PINMUX_DATA(PORT5_BBIF2_TXD1_MARK, PORT5_FN2, MSEL5CR_0_0), \
		PINMUX_DATA(PORT5_FSIAISLD_MARK, PORT5_FN4, MSEL5CR_3_1), \
		PINMUX_DATA(RSPI_SSL0_A_MARK, PORT5_FN6), \
		PINMUX_DATA(LCDVCPWC_1_MARK, PORT5_FN7),
	PINMUX_DATA(DBGMD10_MARK, PORT6_FN1), \
		PINMUX_DATA(PORT6_BBIF2_TSYNC1_MARK, PORT6_FN2, MSEL5CR_0_0), \
		PINMUX_DATA(PORT6_FMSISLD_MARK, PORT6_FN4, MSEL5CR_5_1), \
		PINMUX_DATA(RSPI_SSL1_A_MARK, PORT6_FN6), \
		PINMUX_DATA(LCDVEPWC_1_MARK, PORT6_FN7),
	PINMUX_DATA(FSIAOLR_MARK, PORT7_FN1),
	PINMUX_DATA(FSIAOBT_MARK, PORT8_FN1),
	PINMUX_DATA(FSIAOSLD_MARK, PORT9_FN1), \
		PINMUX_DATA(PORT9_FSIASPDIF_MARK, PORT9_FN2, MSEL5CR_4_0),
	PINMUX_DATA(FSIAOMC_MARK, PORT10_FN1), \
		PINMUX_DATA(PORT10_SCIFA5_RXD_MARK, PORT10_FN3, MSEL5CR_14_0, MSEL5CR_15_0),
	PINMUX_DATA(FSIACK_MARK, PORT11_FN1),
	PINMUX_DATA(FSIAILR_MARK, PORT12_FN1), \
		PINMUX_DATA(PORT12_SCIFA4_RXD_MARK, PORT12_FN2, MSEL5CR_12_0, MSEL5CR_11_0), \
		PINMUX_DATA(LCDRS_1_MARK, PORT12_FN6), \
		PINMUX_DATA(LCDDISP_1_MARK, PORT12_FN7),
	PINMUX_DATA(FSIAIBT_MARK, PORT13_FN1), \
		PINMUX_DATA(PORT13_SCIFA4_TXD_MARK, PORT13_FN2, MSEL5CR_12_0, MSEL5CR_11_0), \
		PINMUX_DATA(LCDRD_1_MARK, PORT13_FN7),
	PINMUX_DATA(FMSOILR_MARK, PORT14_FN1), \
		PINMUX_DATA(FMSIILR_MARK, PORT14_FN2), \
		PINMUX_DATA(VIO_CKO1_MARK, PORT14_FN3), \
		PINMUX_DATA(LCDD23_1_MARK, PORT14_FN7),
	PINMUX_DATA(FMSOIBT_MARK, PORT15_FN1), \
		PINMUX_DATA(FMSIIBT_MARK, PORT15_FN2), \
		PINMUX_DATA(VIO_CKO2_MARK, PORT15_FN3), \
		PINMUX_DATA(LCDD22_1_MARK, PORT15_FN7),
	PINMUX_DATA(FMSOOLR_MARK, PORT16_FN1), \
		PINMUX_DATA(FMSIOLR_MARK, PORT16_FN2),
	PINMUX_DATA(FMSOOBT_MARK, PORT17_FN1), \
		PINMUX_DATA(FMSIOBT_MARK, PORT17_FN2),
	PINMUX_DATA(FMSOSLD_MARK, PORT18_FN1), \
		PINMUX_DATA(PORT18_FSIASPDIF_MARK, PORT18_FN2, MSEL5CR_4_1),
	PINMUX_DATA(FMSICK_MARK, PORT19_FN1), \
		PINMUX_DATA(PORT19_CS5A__MARK, PORT19_FN7, MSEL5CR_2_1),
	PINMUX_DATA(FMSOCK_MARK, PORT20_FN1), \
		PINMUX_DATA(PORT20_SCIFA5_TXD_MARK, PORT20_FN3, MSEL5CR_15_0, MSEL5CR_14_0),
	PINMUX_DATA(SCIFA1_CTS__MARK, PORT21_FN1), \
		PINMUX_DATA(PORT21_SCIFA4_SCK_MARK, PORT21_FN2, MSEL5CR_10_0), \
		PINMUX_DATA(TPU0TO1_MARK, PORT21_FN4), \
		PINMUX_DATA(VIO_FIELD_1_MARK, PORT21_FN5), \
		PINMUX_DATA(STP_IPD5_0_MARK, PORT21_FN6), \
		PINMUX_DATA(LCDD10_1_MARK, PORT21_FN7),
	PINMUX_DATA(PORT22_SCIFA2_SCK_MARK, PORT22_FN1, MSEL5CR_7_0), \
		PINMUX_DATA(PORT22_SIM_D_MARK, PORT22_FN4, MSEL5CR_21_0), \
		PINMUX_DATA(PORT22_VIO_D13_0_MARK, PORT22_FN7, MSEL5CR_27_1),
	PINMUX_DATA(SCIFA1_RTS__MARK, PORT23_FN1), \
		PINMUX_DATA(PORT23_SCIFA5_SCK_MARK, PORT23_FN3, MSEL5CR_13_0), \
		PINMUX_DATA(TPU0TO0_MARK, PORT23_FN4), \
		PINMUX_DATA(VIO_CKO_1_MARK, PORT23_FN5), \
		PINMUX_DATA(STP_IPD2_0_MARK, PORT23_FN6), \
		PINMUX_DATA(LCDD7_1_MARK, PORT23_FN7),
	PINMUX_DATA(PORT24_VIO_D15_0_MARK, PORT24_FN1, MSEL5CR_27_0), \
		PINMUX_DATA(VIO_D7_1_MARK, PORT24_FN5), \
		PINMUX_DATA(SCIFA6_SCK_MARK, PORT24_FN6), \
		PINMUX_DATA(PORT24_SDHICD2_MARK, PORT24_FN7, PORT24_IN_PU, MSEL5CR_19_0),
	PINMUX_DATA(PORT25_VIO_D14_0_MARK, PORT25_FN1, MSEL5CR_27_0), \
		PINMUX_DATA(VIO_D6_1_MARK, PORT25_FN5), \
		PINMUX_DATA(SCIFA6_RXD_MARK, PORT25_FN6), \
		PINMUX_DATA(PORT25_SDHIWP2_MARK, PORT25_FN7, PORT25_IN_PU, MSEL5CR_19_0),
	PINMUX_DATA(PORT26_VIO_D13_0_MARK, PORT26_FN1, MSEL5CR_27_0), \
		PINMUX_DATA(VIO_D5_1_MARK, PORT26_FN5), \
		PINMUX_DATA(SCIFA6_TXD_MARK, PORT26_FN6),
	PINMUX_DATA(VIO_D7_0_MARK, PORT27_FN1),
	PINMUX_DATA(VIO_D6_0_MARK, PORT28_FN1),
	PINMUX_DATA(VIO_D5_0_MARK, PORT29_FN1),
	PINMUX_DATA(VIO_D4_0_MARK, PORT30_FN1),
	PINMUX_DATA(VIO_D3_0_MARK, PORT31_FN1),
	PINMUX_DATA(VIO_D2_0_MARK, PORT32_FN1),
	PINMUX_DATA(VIO_D1_0_MARK, PORT33_FN1),
	PINMUX_DATA(VIO_D0_0_MARK, PORT34_FN1),
	PINMUX_DATA(VIO_CLK_0_MARK, PORT35_FN1),
	PINMUX_DATA(VIO_CKO_MARK, PORT36_FN1),
	PINMUX_DATA(VIO_HD_0_MARK, PORT37_FN1),
	PINMUX_DATA(VIO_FIELD_0_MARK, PORT38_FN1),
	PINMUX_DATA(VIO_VD_0_MARK, PORT39_FN1),
	PINMUX_DATA(PORT40_LCDD18_0_MARK, PORT40_FN4, MSEL5CR_6_0), \
		PINMUX_DATA(RSPI_CK_A_MARK, PORT40_FN6), \
		PINMUX_DATA(LCDLCLK_1_MARK, PORT40_FN7),
	PINMUX_DATA(LCDD17_0_MARK, PORT41_FN1), \
		PINMUX_DATA(MSIOF2_SS1_MARK, PORT41_FN2),
	PINMUX_DATA(LCDD16_0_MARK, PORT42_FN1), \
		PINMUX_DATA(MSIOF2_MCK1_MARK, PORT42_FN2),
	PINMUX_DATA(LCDD15_0_MARK, PORT43_FN1), \
		PINMUX_DATA(MSIOF2_MCK0_MARK, PORT43_FN2), \
		PINMUX_DATA(PORT43_KEYIN0_MARK, PORT43_FN3, MSEL4CR_18_0), \
		PINMUX_DATA(DV_D15_MARK, PORT43_FN6),
	PINMUX_DATA(LCDD14_0_MARK, PORT44_FN1), \
		PINMUX_DATA(MSIOF2_RSYNC_MARK, PORT44_FN2), \
		PINMUX_DATA(PORT44_KEYIN1_MARK, PORT44_FN3, MSEL4CR_18_0), \
		PINMUX_DATA(DV_D14_MARK, PORT44_FN6),
	PINMUX_DATA(LCDD13_0_MARK, PORT45_FN1), \
		PINMUX_DATA(MSIOF2_RSCK_MARK, PORT45_FN2), \
		PINMUX_DATA(PORT45_KEYIN2_MARK, PORT45_FN3, MSEL4CR_18_0), \
		PINMUX_DATA(DV_D13_MARK, PORT45_FN6),
	PINMUX_DATA(LCDD12_0_MARK, PORT46_FN1), \
		PINMUX_DATA(PORT46_KEYIN3_MARK, PORT46_FN3, MSEL4CR_18_0), \
		PINMUX_DATA(DV_D12_MARK, PORT46_FN6),
	PINMUX_DATA(LCDD11_0_MARK, PORT47_FN1), \
		PINMUX_DATA(KEYIN4_MARK, PORT47_FN3), \
		PINMUX_DATA(DV_D11_MARK, PORT47_FN6),
	PINMUX_DATA(LCDD10_0_MARK, PORT48_FN1), \
		PINMUX_DATA(KEYIN5_MARK, PORT48_FN3), \
		PINMUX_DATA(DV_D10_MARK, PORT48_FN6),
	PINMUX_DATA(LCDD9_0_MARK, PORT49_FN1), \
		PINMUX_DATA(KEYIN6_MARK, PORT49_FN3), \
		PINMUX_DATA(DV_D9_MARK, PORT49_FN6),
	PINMUX_DATA(LCDD8_0_MARK, PORT50_FN1), \
		PINMUX_DATA(KEYIN7_MARK, PORT50_FN3), \
		PINMUX_DATA(DV_D8_MARK, PORT50_FN6),
	PINMUX_DATA(LCDD7_0_MARK, PORT51_FN1), \
		PINMUX_DATA(KEYOUT0_MARK, PORT51_FN3), \
		PINMUX_DATA(DV_D7_MARK, PORT51_FN6),
	PINMUX_DATA(LCDD6_0_MARK, PORT52_FN1), \
		PINMUX_DATA(KEYOUT1_MARK, PORT52_FN3), \
		PINMUX_DATA(DV_D6_MARK, PORT52_FN6),
	PINMUX_DATA(LCDD5_0_MARK, PORT53_FN1), \
		PINMUX_DATA(KEYOUT2_MARK, PORT53_FN3), \
		PINMUX_DATA(DV_D5_MARK, PORT53_FN6),
	PINMUX_DATA(LCDD4_0_MARK, PORT54_FN1), \
		PINMUX_DATA(KEYOUT3_MARK, PORT54_FN3), \
		PINMUX_DATA(DV_D4_MARK, PORT54_FN6),
	PINMUX_DATA(LCDD3_0_MARK, PORT55_FN1), \
		PINMUX_DATA(KEYOUT4_MARK, PORT55_FN3), \
		PINMUX_DATA(PORT55_KEYIN3_MARK, PORT55_FN4, MSEL4CR_18_1), \
		PINMUX_DATA(DV_D3_MARK, PORT55_FN6),
	PINMUX_DATA(LCDD2_0_MARK, PORT56_FN1), \
		PINMUX_DATA(KEYOUT5_MARK, PORT56_FN3), \
		PINMUX_DATA(PORT56_KEYIN2_MARK, PORT56_FN4, MSEL4CR_18_1), \
		PINMUX_DATA(DV_D2_MARK, PORT56_FN6),
	PINMUX_DATA(LCDD1_0_MARK, PORT57_FN1), \
		PINMUX_DATA(KEYOUT6_MARK, PORT57_FN3), \
		PINMUX_DATA(PORT57_KEYIN1_MARK, PORT57_FN4, MSEL4CR_18_1), \
		PINMUX_DATA(DV_D1_MARK, PORT57_FN6),
	PINMUX_DATA(LCDD0_0_MARK, PORT58_FN1), \
		PINMUX_DATA(KEYOUT7_MARK, PORT58_FN3), \
		PINMUX_DATA(PORT58_KEYIN0_MARK, PORT58_FN4, MSEL4CR_18_1), \
		PINMUX_DATA(DV_D0_MARK, PORT58_FN6),
	PINMUX_DATA(LCDVCPWC_0_MARK, PORT59_FN1), \
		PINMUX_DATA(PORT59_BBIF2_TSCK1_MARK, PORT59_FN2, MSEL5CR_0_0), \
		PINMUX_DATA(RSPI_MOSI_A_MARK, PORT59_FN6),
	PINMUX_DATA(LCDVEPWC_0_MARK, PORT60_FN1), \
		PINMUX_DATA(PORT60_BBIF2_RXD_MARK, PORT60_FN2, MSEL5CR_0_0), \
		PINMUX_DATA(RSPI_MISO_A_MARK, PORT60_FN6),
	PINMUX_DATA(LCDDON_0_MARK, PORT61_FN1), \
		PINMUX_DATA(MSIOF2_TXD_MARK, PORT61_FN2),
	PINMUX_DATA(LCDDCK_0_MARK, PORT62_FN1), \
		PINMUX_DATA(LCDWR_0_MARK, PORT62_FN4), \
		PINMUX_DATA(DV_CLK_MARK, PORT62_FN6),
	PINMUX_DATA(LCDVSYN_0_MARK, PORT63_FN1), \
		PINMUX_DATA(DV_VSYNC_MARK, PORT63_FN6),
	PINMUX_DATA(LCDHSYN_0_MARK, PORT64_FN1), \
		PINMUX_DATA(LCDCS_0_MARK, PORT64_FN4), \
		PINMUX_DATA(DV_HSYNC_MARK, PORT64_FN6),
	PINMUX_DATA(LCDDISP_0_MARK, PORT65_FN1), \
		PINMUX_DATA(MSIOF2_TSCK_MARK, PORT65_FN2), \
		PINMUX_DATA(LCDRS_0_MARK, PORT65_FN4),
	PINMUX_DATA(MEMC_INT_MARK, PORT66_FN1), \
		PINMUX_DATA(PORT66_TPU0TO2_MARK, PORT66_FN3, MSEL5CR_25_0), \
		PINMUX_DATA(PORT66_MMCCLK0_MARK, PORT66_FN4, MSEL4CR_15_0), \
		PINMUX_DATA(SDHICLK1_MARK, PORT66_FN6),
	PINMUX_DATA(MEMC_CS0_MARK, PORT67_FN1), \
		PINMUX_DATA(PORT67_MSIOF1_SS1_MARK, PORT67_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(PORT67_MMCCMD0_MARK, PORT67_FN4, PORT67_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHICMD1_MARK, PORT67_FN6, PORT67_IN_PU),
	PINMUX_DATA(MEMC_AD8_MARK, PORT68_FN1), \
		PINMUX_DATA(MSIOF1_RSCK_MARK, PORT68_FN2), \
		PINMUX_DATA(PORT68_MMCD0_0_MARK, PORT68_FN4, PORT68_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHID1_0_MARK, PORT68_FN6, PORT68_IN_PU),
	PINMUX_DATA(MEMC_AD9_MARK, PORT69_FN1), \
		PINMUX_DATA(MSIOF1_RSYNC_MARK, PORT69_FN2), \
		PINMUX_DATA(PORT69_MMCD0_1_MARK, PORT69_FN4, PORT69_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHID1_1_MARK, PORT69_FN6, PORT69_IN_PU),
	PINMUX_DATA(MEMC_AD10_MARK, PORT70_FN1), \
		PINMUX_DATA(MSIOF1_MCK0_MARK, PORT70_FN2), \
		PINMUX_DATA(PORT70_MMCD0_2_MARK, PORT70_FN4, PORT70_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHID1_2_MARK, PORT70_FN6, PORT70_IN_PU),
	PINMUX_DATA(MEMC_AD11_MARK, PORT71_FN1), \
		PINMUX_DATA(MSIOF1_MCK1_MARK, PORT71_FN2), \
		PINMUX_DATA(PORT71_MMCD0_3_MARK, PORT71_FN4, PORT71_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHID1_3_MARK, PORT71_FN6, PORT71_IN_PU),
	PINMUX_DATA(MEMC_AD12_MARK, PORT72_FN1), \
		PINMUX_DATA(PORT72_MSIOF1_TSCK_MARK, PORT72_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(PORT72_MMCD0_4_MARK, PORT72_FN4, PORT72_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHICD1_MARK, PORT72_FN6, PORT72_IN_PU),
	PINMUX_DATA(MEMC_AD13_MARK, PORT73_FN1), \
		PINMUX_DATA(PORT73_MSIOF1_TSYNC_MARK, PORT73_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(PORT73_MMCD0_5_MARK, PORT73_FN4, PORT73_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(SDHIWP1_MARK, PORT73_FN6, PORT73_IN_PU),
	PINMUX_DATA(MEMC_AD14_MARK, PORT74_FN1), \
		PINMUX_DATA(PORT74_MSIOF1_TXD_MARK, PORT74_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(PORT74_MMCD0_6_MARK, PORT74_FN4, PORT74_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(STP_IPD7_1_MARK, PORT74_FN6), \
		PINMUX_DATA(LCDD21_1_MARK, PORT74_FN7),
	PINMUX_DATA(MEMC_AD15_MARK, PORT75_FN1), \
		PINMUX_DATA(PORT75_MSIOF1_RXD_MARK, PORT75_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(PORT75_MMCD0_7_MARK, PORT75_FN4, PORT75_IN_PU, MSEL4CR_15_0), \
		PINMUX_DATA(STP_IPD6_1_MARK, PORT75_FN6), \
		PINMUX_DATA(LCDD20_1_MARK, PORT75_FN7),
	PINMUX_DATA(SDHICMD0_MARK, PORT76_FN1, PORT76_IN_PU),
	PINMUX_DATA(SDHID0_0_MARK, PORT77_FN1, PORT77_IN_PU),
	PINMUX_DATA(SDHID0_1_MARK, PORT78_FN1, PORT78_IN_PU),
	PINMUX_DATA(SDHID0_2_MARK, PORT79_FN1, PORT79_IN_PU),
	PINMUX_DATA(SDHID0_3_MARK, PORT80_FN1, PORT80_IN_PU),
	PINMUX_DATA(SDHICD0_MARK, PORT81_FN1, PORT81_IN_PU),
	PINMUX_DATA(SDHICLK0_MARK, PORT82_FN1),
	PINMUX_DATA(SDHIWP0_MARK, PORT83_FN1, PORT83_IN_PU),
	PINMUX_DATA(RESETOUTS__MARK, PORT84_FN1),
	PINMUX_DATA(PPON_0_MARK, PORT85_FN1),
	PINMUX_DATA(OCI_0_MARK, PORT86_FN1),
	PINMUX_DATA(PPON_1_MARK, PORT87_FN1),
	PINMUX_DATA(OCI_1_MARK, PORT88_FN1),
	PINMUX_DATA(DREQ0_MARK, PORT89_FN1), \
		PINMUX_DATA(PORT89_BBIF2_TSCK1_MARK, PORT89_FN2, MSEL5CR_0_1), \
		PINMUX_DATA(RSPI_SSL3_A_MARK, PORT89_FN6),
	PINMUX_DATA(DACK0_MARK, PORT90_FN1), \
		PINMUX_DATA(PORT90_BBIF2_RXD_MARK, PORT90_FN2, MSEL5CR_0_1), \
		PINMUX_DATA(RSPI_SSL2_A_MARK, PORT90_FN6), \
		PINMUX_DATA(PORT90_WAIT__MARK, PORT90_FN7, MSEL5CR_2_1),
	PINMUX_DATA(MEMC_AD0_MARK, PORT91_FN1), \
		PINMUX_DATA(BBIF1_RXD_MARK, PORT91_FN2), \
		PINMUX_DATA(PORT91_SCIFA5_TXD_MARK, PORT91_FN3, MSEL5CR_15_1, MSEL5CR_14_0), \
		PINMUX_DATA(LCDD5_1_MARK, PORT91_FN7),
	PINMUX_DATA(MEMC_AD1_MARK, PORT92_FN1), \
		PINMUX_DATA(BBIF1_TSYNC_MARK, PORT92_FN2), \
		PINMUX_DATA(PORT92_SCIFA5_RXD_MARK, PORT92_FN3, MSEL5CR_15_1, MSEL5CR_14_0), \
		PINMUX_DATA(STP_IPD1_0_MARK, PORT92_FN6), \
		PINMUX_DATA(LCDD6_1_MARK, PORT92_FN7),
	PINMUX_DATA(MEMC_AD2_MARK, PORT93_FN1), \
		PINMUX_DATA(BBIF1_TSCK_MARK, PORT93_FN2), \
		PINMUX_DATA(PORT93_SCIFA4_TXD_MARK, PORT93_FN3, MSEL5CR_12_1, MSEL5CR_11_0), \
		PINMUX_DATA(STP_IPD3_0_MARK, PORT93_FN6), \
		PINMUX_DATA(LCDD8_1_MARK, PORT93_FN7),
	PINMUX_DATA(MEMC_AD3_MARK, PORT94_FN1), \
		PINMUX_DATA(BBIF1_TXD_MARK, PORT94_FN2), \
		PINMUX_DATA(PORT94_SCIFA4_RXD_MARK, PORT94_FN3, MSEL5CR_12_1, MSEL5CR_11_0), \
		PINMUX_DATA(STP_IPD4_0_MARK, PORT94_FN6), \
		PINMUX_DATA(LCDD9_1_MARK, PORT94_FN7),
	PINMUX_DATA(MEMC_CS1_MEMC_A1_MARK, PORT95_FN1), \
		PINMUX_DATA(SCIFA2_CTS__MARK, PORT95_FN2), \
		PINMUX_DATA(STM_RST_MARK, PORT95_FN4), \
		PINMUX_DATA(PORT95_VIO_D14_0_MARK, PORT95_FN7, MSEL5CR_27_1),
	PINMUX_DATA(MEMC_ADV_MEMC_DREQ0_MARK, PORT96_FN1), \
		PINMUX_DATA(SCIFA2_RTS__MARK, PORT96_FN2), \
		PINMUX_DATA(STM_CLK_MARK, PORT96_FN4), \
		PINMUX_DATA(PORT96_VIO_D15_0_MARK, PORT96_FN7, MSEL5CR_27_1),
	PINMUX_DATA(MEMC_AD4_MARK, PORT97_FN1), \
		PINMUX_DATA(BBIF1_RSCK_MARK, PORT97_FN2), \
		PINMUX_DATA(LCDCS_1_MARK, PORT97_FN6), \
		PINMUX_DATA(LCDHSYN_1_MARK, PORT97_FN7),
	PINMUX_DATA(MEMC_AD5_MARK, PORT98_FN1), \
		PINMUX_DATA(BBIF1_RSYNC_MARK, PORT98_FN2), \
		PINMUX_DATA(LCDVSYN_1_MARK, PORT98_FN7),
	PINMUX_DATA(MEMC_AD6_MARK, PORT99_FN1), \
		PINMUX_DATA(BBIF1_FLOW_MARK, PORT99_FN2), \
		PINMUX_DATA(LCDWR_1_MARK, PORT99_FN6), \
		PINMUX_DATA(LCDDCK_1_MARK, PORT99_FN7),
	PINMUX_DATA(MEMC_AD7_MARK, PORT100_FN1), \
		PINMUX_DATA(BB_RX_FLOW_N_MARK, PORT100_FN2), \
		PINMUX_DATA(LCDDON_1_MARK, PORT100_FN7),
	PINMUX_DATA(FCE0__MARK, PORT101_FN1),
	PINMUX_DATA(FRB_MARK, PORT102_FN1), \
		PINMUX_DATA(PORT102_LCDLCLK_0_MARK, PORT102_FN4, MSEL5CR_6_0),
	PINMUX_DATA(CS5B__MARK, PORT103_FN1), \
		PINMUX_DATA(FCE1__MARK, PORT103_FN2), \
		PINMUX_DATA(PORT103_MMCCLK0_MARK, PORT103_FN3, MSEL4CR_15_1),
	PINMUX_DATA(CS6A__MARK, PORT104_FN1), \
		PINMUX_DATA(PORT104_MMCCMD0_MARK, PORT104_FN3, PORT104_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(PORT105_CS5A__MARK, PORT105_FN1, MSEL5CR_2_0), \
		PINMUX_DATA(PORT105_SCIFA3_RTS__MARK, PORT105_FN4, MSEL5CR_8_0),
	PINMUX_DATA(IOIS16__MARK, PORT106_FN1), \
		PINMUX_DATA(EXBUF_ENB__MARK, PORT106_FN6),
	PINMUX_DATA(WE3__MARK, PORT107_FN1),
	PINMUX_DATA(WE2__MARK, PORT108_FN1),
	PINMUX_DATA(CS0__MARK, PORT109_FN1),
	PINMUX_DATA(CS2__MARK, PORT110_FN1),
	PINMUX_DATA(CS4__MARK, PORT111_FN1),
	PINMUX_DATA(WE1__MARK, PORT112_FN1),
	PINMUX_DATA(WE0_FWE_MARK, PORT113_FN1),
	PINMUX_DATA(RDWR_MARK, PORT114_FN1),
	PINMUX_DATA(RD_FSC_MARK, PORT115_FN1),
	PINMUX_DATA(A25_MARK, PORT116_FN1), \
		PINMUX_DATA(MSIOF0_SS2_MARK, PORT116_FN2), \
		PINMUX_DATA(PORT116_MSIOF1_SS2_MARK, PORT116_FN3, MSEL4CR_10_0), \
		PINMUX_DATA(PORT116_SCIFA3_SCK_MARK, PORT116_FN4, MSEL5CR_8_0),
	PINMUX_DATA(A24_MARK, PORT117_FN1), \
		PINMUX_DATA(MSIOF0_SS2_MARK, PORT117_FN2), \
		PINMUX_DATA(PORT117_MSIOF1_SS1_MARK, PORT117_FN3, MSEL4CR_10_0), \
		PINMUX_DATA(PORT117_SCIFA3_CTS__MARK, PORT117_FN4, MSEL5CR_8_0),
	PINMUX_DATA(A23_MARK, PORT118_FN1), \
		PINMUX_DATA(MSIOF0_MCK1_MARK, PORT118_FN2), \
		PINMUX_DATA(PORT118_MSIOF1_RXD_MARK, PORT118_FN3, MSEL4CR_10_0),
	PINMUX_DATA(A22_MARK, PORT119_FN1), \
		PINMUX_DATA(MSIOF0_MCK0_MARK, PORT119_FN2), \
		PINMUX_DATA(PORT119_MSIOF1_TXD_MARK, PORT119_FN3, MSEL4CR_10_0),
	PINMUX_DATA(A21_MARK, PORT120_FN1), \
		PINMUX_DATA(MSIOF0_RSYNC_MARK, PORT120_FN2), \
		PINMUX_DATA(PORT120_MSIOF1_TSYNC_MARK, PORT120_FN3, MSEL4CR_10_0),
	PINMUX_DATA(A20_MARK, PORT121_FN1), \
		PINMUX_DATA(MSIOF0_RSCK_MARK, PORT121_FN2), \
		PINMUX_DATA(PORT121_MSIOF1_TSCK_MARK, PORT121_FN3, MSEL4CR_10_0),
	PINMUX_DATA(A19_MARK, PORT122_FN1), \
		PINMUX_DATA(MSIOF0_RXD_MARK, PORT122_FN2),
	PINMUX_DATA(A18_MARK, PORT123_FN1), \
		PINMUX_DATA(MSIOF0_TSCK_MARK, PORT123_FN2),
	PINMUX_DATA(A17_MARK, PORT124_FN1), \
		PINMUX_DATA(MSIOF0_TSYNC_MARK, PORT124_FN2),
	PINMUX_DATA(A16_MARK, PORT125_FN1),
	PINMUX_DATA(A15_MARK, PORT126_FN1),
	PINMUX_DATA(A14_MARK, PORT127_FN1),
	PINMUX_DATA(A13_MARK, PORT128_FN1),
	PINMUX_DATA(A12_MARK, PORT129_FN1),
	PINMUX_DATA(A11_MARK, PORT130_FN1),
	PINMUX_DATA(A10_MARK, PORT131_FN1),
	PINMUX_DATA(A9_MARK, PORT132_FN1),
	PINMUX_DATA(A8_MARK, PORT133_FN1),
	PINMUX_DATA(A7_MARK, PORT134_FN1),
	PINMUX_DATA(A6_MARK, PORT135_FN1),
	PINMUX_DATA(A5_FCDE_MARK, PORT136_FN1),
	PINMUX_DATA(A4_FOE_MARK, PORT137_FN1),
	PINMUX_DATA(A3_MARK, PORT138_FN1),
	PINMUX_DATA(A2_MARK, PORT139_FN1),
	PINMUX_DATA(A1_MARK, PORT140_FN1),
	PINMUX_DATA(CKO_MARK, PORT141_FN1),
	PINMUX_DATA(D15_MARK, PORT142_FN1), \
		PINMUX_DATA(PORT142_MMCD0_7_MARK, PORT142_FN3, PORT142_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D14_MARK, PORT143_FN1), \
		PINMUX_DATA(PORT143_MMCD0_6_MARK, PORT143_FN3, PORT143_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D13_MARK, PORT144_FN1), \
		PINMUX_DATA(PORT144_MMCD0_5_MARK, PORT144_FN3, PORT144_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D12_MARK, PORT145_FN1), \
		PINMUX_DATA(PORT145_MMCD0_4_MARK, PORT145_FN3, PORT145_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D11_MARK, PORT146_FN1), \
		PINMUX_DATA(PORT146_MMCD0_3_MARK, PORT146_FN3, PORT146_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D10_MARK, PORT147_FN1), \
		PINMUX_DATA(PORT147_MMCD0_2_MARK, PORT147_FN3, PORT147_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D9_MARK, PORT148_FN1), \
		PINMUX_DATA(PORT148_MMCD0_1_MARK, PORT148_FN3, PORT148_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D8_MARK, PORT149_FN1), \
		PINMUX_DATA(PORT149_MMCD0_0_MARK, PORT149_FN3, PORT149_IN_PU, MSEL4CR_15_1),
	PINMUX_DATA(D7_MARK, PORT150_FN1),
	PINMUX_DATA(D6_MARK, PORT151_FN1),
	PINMUX_DATA(D5_MARK, PORT152_FN1),
	PINMUX_DATA(D4_MARK, PORT153_FN1),
	PINMUX_DATA(D3_MARK, PORT154_FN1),
	PINMUX_DATA(D2_MARK, PORT155_FN1),
	PINMUX_DATA(D1_MARK, PORT156_FN1),
	PINMUX_DATA(D0_MARK, PORT157_FN1),
	PINMUX_DATA(D31_MARK, PORT158_FN1), \
		PINMUX_DATA(PORT158_SCIFA3_SCK_MARK, PORT158_FN2, MSEL5CR_8_1), \
		PINMUX_DATA(REF125CK_MARK, PORT158_FN3), \
		PINMUX_DATA(PORT158_LCDD21_0_MARK, PORT158_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IRDA_FIRSEL_MARK, PORT158_FN5), \
		PINMUX_DATA(IDED15_MARK, PORT158_FN6),
	PINMUX_DATA(D30_MARK, PORT159_FN1), \
		PINMUX_DATA(PORT159_SCIFA3_RXD_MARK, PORT159_FN2, MSEL5CR_8_1), \
		PINMUX_DATA(REF50CK_MARK, PORT159_FN3), \
		PINMUX_DATA(PORT159_LCDD23_0_MARK, PORT159_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IDED14_MARK, PORT159_FN6),
	PINMUX_DATA(D29_MARK, PORT160_FN1), \
		PINMUX_DATA(PORT160_SCIFA3_TXD_MARK, PORT160_FN2, MSEL5CR_8_1), \
		PINMUX_DATA(PORT160_LCDD22_0_MARK, PORT160_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(VIO_HD_1_MARK, PORT160_FN5), \
		PINMUX_DATA(IDED13_MARK, PORT160_FN6),
	PINMUX_DATA(D28_MARK, PORT161_FN1), \
		PINMUX_DATA(PORT161_SCIFA3_RTS__MARK, PORT161_FN2, MSEL5CR_8_1), \
		PINMUX_DATA(ET_RX_DV_MARK, PORT161_FN3), \
		PINMUX_DATA(PORT161_LCDD20_0_MARK, PORT161_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IRDA_IN_MARK, PORT161_FN5), \
		PINMUX_DATA(IDED12_MARK, PORT161_FN6),
	PINMUX_DATA(D27_MARK, PORT162_FN1), \
		PINMUX_DATA(PORT162_SCIFA3_CTS__MARK, PORT162_FN2, MSEL5CR_8_1), \
		PINMUX_DATA(PORT162_LCDD19_0_MARK, PORT162_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IRDA_OUT_MARK, PORT162_FN5), \
		PINMUX_DATA(IDED11_MARK, PORT162_FN6),
	PINMUX_DATA(D26_MARK, PORT163_FN1), \
		PINMUX_DATA(MSIOF2_SS2_MARK, PORT163_FN2), \
		PINMUX_DATA(ET_COL_MARK, PORT163_FN3), \
		PINMUX_DATA(PORT163_LCDD18_0_MARK, PORT163_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IROUT_MARK, PORT163_FN5), \
		PINMUX_DATA(IDED10_MARK, PORT163_FN6),
	PINMUX_DATA(D25_MARK, PORT164_FN1), \
		PINMUX_DATA(MSIOF2_TSYNC_MARK, PORT164_FN2), \
		PINMUX_DATA(ET_PHY_INT_MARK, PORT164_FN3), \
		PINMUX_DATA(LCDRD_0_MARK, PORT164_FN4), \
		PINMUX_DATA(IDED9_MARK, PORT164_FN6),
	PINMUX_DATA(D24_MARK, PORT165_FN1), \
		PINMUX_DATA(MSIOF2_RXD_MARK, PORT165_FN2), \
		PINMUX_DATA(PORT165_LCDLCLK_0_MARK, PORT165_FN4, MSEL5CR_6_1), \
		PINMUX_DATA(IDED8_MARK, PORT165_FN6),
	PINMUX_DATA(D21_MARK, PORT166_FN1), \
		PINMUX_DATA(ET_ETXD5_MARK, PORT166_FN3), \
		PINMUX_DATA(IDED5_MARK, PORT166_FN6),
	PINMUX_DATA(D20_MARK, PORT167_FN1), \
		PINMUX_DATA(ET_ETXD4_MARK, PORT167_FN3), \
		PINMUX_DATA(IDED4_MARK, PORT167_FN6),
	PINMUX_DATA(D19_MARK, PORT168_FN1), \
		PINMUX_DATA(ET_ETXD3_MARK, PORT168_FN3), \
		PINMUX_DATA(IDED3_MARK, PORT168_FN6),
	PINMUX_DATA(D18_MARK, PORT169_FN1), \
		PINMUX_DATA(ET_ETXD2_MARK, PORT169_FN3), \
		PINMUX_DATA(IDED2_MARK, PORT169_FN6),
	PINMUX_DATA(D17_MARK, PORT170_FN1), \
		PINMUX_DATA(ET_ETXD1_MARK, PORT170_FN3), \
		PINMUX_DATA(IDED1_MARK, PORT170_FN6),
	PINMUX_DATA(D16_MARK, PORT171_FN1), \
		PINMUX_DATA(ET_ETXD0_MARK, PORT171_FN3), \
		PINMUX_DATA(IDED0_MARK, PORT171_FN6),
	PINMUX_DATA(D23_MARK, PORT172_FN1), \
		PINMUX_DATA(PORT172_SCIFB_RTS__MARK, PORT172_FN2, MSEL5CR_17_1), \
		PINMUX_DATA(ET_ETXD7_MARK, PORT172_FN3), \
		PINMUX_DATA(IDED7_MARK, PORT172_FN6),
	PINMUX_DATA(D22_MARK, PORT173_FN1), \
		PINMUX_DATA(PORT173_SCIFB_CTS__MARK, PORT173_FN2, MSEL5CR_17_1), \
		PINMUX_DATA(ET_ETXD6_MARK, PORT173_FN3), \
		PINMUX_DATA(IDED6_MARK, PORT173_FN6),
	PINMUX_DATA(A26_MARK, PORT174_FN1), \
		PINMUX_DATA(MSIOF0_TXD_MARK, PORT174_FN2), \
		PINMUX_DATA(ET_RX_CLK_MARK, PORT174_FN3), \
		PINMUX_DATA(PORT174_SCIFA3_RXD_MARK, PORT174_FN4, MSEL5CR_8_0),
	PINMUX_DATA(A0_MARK, PORT175_FN1), \
		PINMUX_DATA(BS_MARK, PORT175_FN2), \
		PINMUX_DATA(ET_MAGIC_MARK, PORT175_FN3), \
		PINMUX_DATA(PORT175_SCIFA3_TXD_MARK, PORT175_FN4, MSEL5CR_8_0),
	PINMUX_DATA(ET_GTX_CLK_MARK, PORT176_FN3),
	PINMUX_DATA(PORT177_WAIT__MARK, PORT177_FN1, MSEL5CR_2_0), \
		PINMUX_DATA(ET_LINK_MARK, PORT177_FN3), \
		PINMUX_DATA(IDEIOWR__MARK, PORT177_FN6), \
		PINMUX_DATA(PORT177_SDHIWP2_MARK, PORT177_FN7, PORT177_IN_PU, MSEL5CR_19_1),
	PINMUX_DATA(VIO_D12_0_MARK, PORT178_FN1), \
		PINMUX_DATA(VIO_D4_1_MARK, PORT178_FN5), \
		PINMUX_DATA(IDEIORD__MARK, PORT178_FN6),
	PINMUX_DATA(VIO_D11_0_MARK, PORT179_FN1), \
		PINMUX_DATA(VIO_D3_1_MARK, PORT179_FN5), \
		PINMUX_DATA(IDEIORDY_MARK, PORT179_FN6),
	PINMUX_DATA(VIO_D10_0_MARK, PORT180_FN1), \
		PINMUX_DATA(TPU0TO3_MARK, PORT180_FN4), \
		PINMUX_DATA(VIO_D2_1_MARK, PORT180_FN5), \
		PINMUX_DATA(IDEINT_MARK, PORT180_FN6),
	PINMUX_DATA(VIO_D9_0_MARK, PORT181_FN1), \
		PINMUX_DATA(VIO_D1_1_MARK, PORT181_FN5), \
		PINMUX_DATA(IDERST__MARK, PORT181_FN6),
	PINMUX_DATA(VIO_D8_0_MARK, PORT182_FN1), \
		PINMUX_DATA(VIO_D0_1_MARK, PORT182_FN5), \
		PINMUX_DATA(DIRECTION_MARK, PORT182_FN6),
	PINMUX_DATA(DREQ1_MARK, PORT183_FN1), \
		PINMUX_DATA(PORT183_BBIF2_TXD1_MARK, PORT183_FN2, MSEL5CR_0_1), \
		PINMUX_DATA(ET_TX_EN_MARK, PORT183_FN3),
	PINMUX_DATA(DACK1_MARK, PORT184_FN1), \
		PINMUX_DATA(PORT184_BBIF2_TSYNC1_MARK, PORT184_FN2, MSEL5CR_0_1), \
		PINMUX_DATA(ET_TX_CLK_MARK, PORT184_FN3),
	PINMUX_DATA(SCIFA1_SCK_MARK, PORT185_FN1), \
		PINMUX_DATA(ET_ERXD0_MARK, PORT185_FN3), \
		PINMUX_DATA(STP_IPCLK_1_MARK, PORT185_FN6),
	PINMUX_DATA(PORT186_SCIFB_RTS__MARK, PORT186_FN1, MSEL5CR_17_0), \
		PINMUX_DATA(ET_ERXD1_MARK, PORT186_FN3), \
		PINMUX_DATA(PORT186_STP_IPD0_1_MARK, PORT186_FN6, MSEL5CR_23_0),
	PINMUX_DATA(PORT187_SCIFB_CTS__MARK, PORT187_FN1, MSEL5CR_17_0), \
		PINMUX_DATA(ET_ERXD2_MARK, PORT187_FN3), \
		PINMUX_DATA(PORT187_STP_IPEN_1_MARK, PORT187_FN6, MSEL5CR_23_0),
	PINMUX_DATA(SCIFA0_SCK_MARK, PORT188_FN1), \
		PINMUX_DATA(ET_ERXD3_MARK, PORT188_FN3), \
		PINMUX_DATA(STP_IPSYNC_1_MARK, PORT188_FN6),
	PINMUX_DATA(ET_ERXD4_MARK, PORT189_FN3), \
		PINMUX_DATA(STP_IPCLK_0_MARK, PORT189_FN6),
	PINMUX_DATA(PORT190_SCIFB_SCK_MARK, PORT190_FN1, MSEL5CR_17_0), \
		PINMUX_DATA(ET_ERXD5_MARK, PORT190_FN3), \
		PINMUX_DATA(STP_IPD0_0_MARK, PORT190_FN6),
	PINMUX_DATA(PORT191_SCIFB_RXD_MARK, PORT191_FN1, MSEL5CR_17_0), \
		PINMUX_DATA(ET_ERXD6_MARK, PORT191_FN3), \
		PINMUX_DATA(STP_IPEN_0_MARK, PORT191_FN6),
	PINMUX_DATA(PORT192_SCIFB_TXD_MARK, PORT192_FN1, MSEL5CR_17_0), \
		PINMUX_DATA(ET_ERXD7_MARK, PORT192_FN3), \
		PINMUX_DATA(STP_IPSYNC_0_MARK, PORT192_FN6),
	PINMUX_DATA(SCIFA0_CTS__MARK, PORT193_FN1), \
		PINMUX_DATA(RMII_CRS_DV_MARK, PORT193_FN3), \
		PINMUX_DATA(PORT193_STP_IPEN_1_MARK, PORT193_FN6, MSEL5CR_23_1), \
		PINMUX_DATA(LCDD17_1_MARK, PORT193_FN7),
	PINMUX_DATA(SCIFA0_RTS__MARK, PORT194_FN1), \
		PINMUX_DATA(RMII_RX_ER_MARK, PORT194_FN3), \
		PINMUX_DATA(PORT194_STP_IPD0_1_MARK, PORT194_FN6, MSEL5CR_23_1), \
		PINMUX_DATA(LCDD16_1_MARK, PORT194_FN7),
	PINMUX_DATA(SCIFA1_RXD_MARK, PORT195_FN1), \
		PINMUX_DATA(RMII_RXD0_MARK, PORT195_FN3), \
		PINMUX_DATA(STP_IPD3_1_MARK, PORT195_FN6), \
		PINMUX_DATA(LCDD15_1_MARK, PORT195_FN7),
	PINMUX_DATA(SCIFA1_TXD_MARK, PORT196_FN1), \
		PINMUX_DATA(RMII_RXD1_MARK, PORT196_FN3), \
		PINMUX_DATA(STP_IPD2_1_MARK, PORT196_FN6), \
		PINMUX_DATA(LCDD14_1_MARK, PORT196_FN7),
	PINMUX_DATA(SCIFA0_RXD_MARK, PORT197_FN1), \
		PINMUX_DATA(VIO_CLK_1_MARK, PORT197_FN5), \
		PINMUX_DATA(STP_IPD5_1_MARK, PORT197_FN6), \
		PINMUX_DATA(LCDD19_1_MARK, PORT197_FN7),
	PINMUX_DATA(SCIFA0_TXD_MARK, PORT198_FN1), \
		PINMUX_DATA(VIO_VD_1_MARK, PORT198_FN5), \
		PINMUX_DATA(STP_IPD4_1_MARK, PORT198_FN6), \
		PINMUX_DATA(LCDD18_1_MARK, PORT198_FN7),
	PINMUX_DATA(MEMC_NWE_MARK, PORT199_FN1), \
		PINMUX_DATA(PORT199_SCIFA2_SCK_MARK, PORT199_FN2, MSEL5CR_7_1), \
		PINMUX_DATA(RMII_TX_EN_MARK, PORT199_FN3), \
		PINMUX_DATA(PORT199_SIM_D_MARK, PORT199_FN4, MSEL5CR_21_1), \
		PINMUX_DATA(STP_IPD1_1_MARK, PORT199_FN6), \
		PINMUX_DATA(LCDD13_1_MARK, PORT199_FN7),
	PINMUX_DATA(MEMC_NOE_MARK, PORT200_FN1), \
		PINMUX_DATA(SCIFA2_RXD_MARK, PORT200_FN2), \
		PINMUX_DATA(RMII_TXD0_MARK, PORT200_FN3), \
		PINMUX_DATA(STP_IPD7_0_MARK, PORT200_FN6), \
		PINMUX_DATA(LCDD12_1_MARK, PORT200_FN7),
	PINMUX_DATA(MEMC_WAIT_MEMC_DREQ1_MARK, PORT201_FN1), \
		PINMUX_DATA(SCIFA2_TXD_MARK, PORT201_FN2), \
		PINMUX_DATA(RMII_TXD1_MARK, PORT201_FN3), \
		PINMUX_DATA(STP_IPD6_0_MARK, PORT201_FN6), \
		PINMUX_DATA(LCDD11_1_MARK, PORT201_FN7),
	PINMUX_DATA(MEME_BUSCLK_MEMC_A0_MARK, PORT202_FN1), \
		PINMUX_DATA(PORT202_MSIOF1_SS2_MARK, PORT202_FN2, MSEL4CR_10_1), \
		PINMUX_DATA(RMII_MDC_MARK, PORT202_FN3), \
		PINMUX_DATA(PORT202_TPU0TO2_MARK, PORT202_FN4, MSEL5CR_25_1), \
		PINMUX_DATA(IDECS0__MARK, PORT202_FN6), \
		PINMUX_DATA(PORT202_SDHICD2_MARK, PORT202_FN7, PORT202_IN_PU, MSEL5CR_19_1),
	PINMUX_DATA(SDHICLK2_MARK, PORT203_FN1, PORT203_IN_PU), \
		PINMUX_DATA(ET_TX_ER_MARK, PORT203_FN3), \
		PINMUX_DATA(IDEA2_MARK, PORT203_FN6), \
		PINMUX_DATA(PORT203_SCIFA4_TXD_MARK, PORT203_FN7, MSEL5CR_12_0, MSEL5CR_11_1),
	PINMUX_DATA(SDHICMD2_MARK, PORT204_FN1, PORT204_IN_PU), \
		PINMUX_DATA(ET_RX_ER_MARK, PORT204_FN3), \
		PINMUX_DATA(IDEA1_MARK, PORT204_FN6), \
		PINMUX_DATA(PORT204_SCIFA4_RXD_MARK, PORT204_FN7, MSEL5CR_12_0, MSEL5CR_11_1),
	PINMUX_DATA(SDHID2_0_MARK, PORT205_FN1, PORT205_IN_PU), \
		PINMUX_DATA(ET_CRS_MARK, PORT205_FN3), \
		PINMUX_DATA(IDEA0_MARK, PORT205_FN6), \
		PINMUX_DATA(PORT205_SCIFA4_SCK_MARK, PORT205_FN7, MSEL5CR_10_1),
	PINMUX_DATA(SDHID2_1_MARK, PORT206_FN1, PORT206_IN_PU), \
		PINMUX_DATA(ET_MDC_MARK, PORT206_FN3), \
		PINMUX_DATA(IODACK__MARK, PORT206_FN6), \
		PINMUX_DATA(PORT206_SCIFA5_SCK_MARK, PORT206_FN7, MSEL5CR_13_1),
	PINMUX_DATA(SDHID2_2_MARK, PORT207_FN1, PORT207_IN_PU), \
		PINMUX_DATA(ET_MDIO_MARK, PORT207_FN3), \
		PINMUX_DATA(IODREQ_MARK, PORT207_FN6), \
		PINMUX_DATA(PORT207_SCIFA5_RXD_MARK, PORT207_FN7, MSEL5CR_15_0, MSEL5CR_14_1),
	PINMUX_DATA(SDHID2_3_MARK, PORT208_FN1, PORT208_IN_PU), \
		PINMUX_DATA(RMII_MDIO_MARK, PORT208_FN3), \
		PINMUX_DATA(IDECS1__MARK, PORT208_FN6), \
		PINMUX_DATA(PORT208_SCIFA5_TXD_MARK, PORT208_FN7, MSEL5CR_15_0, MSEL5CR_14_1),
	PINMUX_DATA(VBUS_MARK, PORT209_FN1),
};

#define _GPIO_PORT(pfx, sfx) PINMUX_GPIO(GPIO_PORT##pfx, PORT##pfx##_DATA)
#define GPIO_PORT_ALL() _211(_GPIO_PORT, , unused)
#define GPIO_FN(str) PINMUX_GPIO(GPIO_FN_##str, str##_MARK)

static struct pinmux_gpio pinmux_gpios[] = {

	/* PORT */
	GPIO_PORT_ALL(),

	/* IRQ */
	GPIO_FN(IRQ0_2),   GPIO_FN(IRQ0_13),
	GPIO_FN(IRQ1_20),
	GPIO_FN(IRQ2_11),  GPIO_FN(IRQ2_12),
	GPIO_FN(IRQ3_10),  GPIO_FN(IRQ3_14),
	GPIO_FN(IRQ4_15),  GPIO_FN(IRQ4_172),
	GPIO_FN(IRQ5_0),   GPIO_FN(IRQ5_1),
	GPIO_FN(IRQ6_121), GPIO_FN(IRQ6_173),
	GPIO_FN(IRQ7_120), GPIO_FN(IRQ7_209),
	GPIO_FN(IRQ8_119),
	GPIO_FN(IRQ9_118), GPIO_FN(IRQ9_210),
	GPIO_FN(IRQ10_19),
	GPIO_FN(IRQ11_104),
	GPIO_FN(IRQ12_42), GPIO_FN(IRQ12_97),
	GPIO_FN(IRQ13_64), GPIO_FN(IRQ13_98),
	GPIO_FN(IRQ14_63), GPIO_FN(IRQ14_99),
	GPIO_FN(IRQ15_62), GPIO_FN(IRQ15_100),
	GPIO_FN(IRQ16_68), GPIO_FN(IRQ16_211),
	GPIO_FN(IRQ17_69),
	GPIO_FN(IRQ18_70),
	GPIO_FN(IRQ19_71),
	GPIO_FN(IRQ20_67),
	GPIO_FN(IRQ21_202),
	GPIO_FN(IRQ22_95),
	GPIO_FN(IRQ23_96),
	GPIO_FN(IRQ24_180),
	GPIO_FN(IRQ25_38),
	GPIO_FN(IRQ26_58), GPIO_FN(IRQ26_81),
	GPIO_FN(IRQ27_57), GPIO_FN(IRQ27_168),
	GPIO_FN(IRQ28_56), GPIO_FN(IRQ28_169),
	GPIO_FN(IRQ29_50), GPIO_FN(IRQ29_170),
	GPIO_FN(IRQ30_49), GPIO_FN(IRQ30_171),
	GPIO_FN(IRQ31_41), GPIO_FN(IRQ31_167),

	/* Functions 0-7 */
	GPIO_FN(DBGMDT2), GPIO_FN(PORT0_FSIAISLD), GPIO_FN(FSIAOSLD1), GPIO_FN(PORT0_LCDD22_0), GPIO_FN(SCIFA7_RXD), GPIO_FN(LCDD4_1),
	GPIO_FN(DBGMDT1), GPIO_FN(PORT1_FMSISLD), GPIO_FN(FSIAOSLD2), GPIO_FN(PORT1_LCDD23_0), GPIO_FN(SCIFA7_TXD), GPIO_FN(LCDD3_1),
	GPIO_FN(DBGMDT0), GPIO_FN(PORT2_SCIFB_SCK), GPIO_FN(PORT2_LCDD21_0), GPIO_FN(LCDD2_1),
	GPIO_FN(DBGMD21), GPIO_FN(PORT3_SCIFB_RXD), GPIO_FN(PORT3_LCDD20_0), GPIO_FN(LCDD1_1),
	GPIO_FN(DBGMD20), GPIO_FN(PORT4_SCIFB_TXD), GPIO_FN(PORT4_LCDD19_0), GPIO_FN(LCDD0_1),
	GPIO_FN(DBGMD11), GPIO_FN(PORT5_BBIF2_TXD1), GPIO_FN(PORT5_FSIAISLD), GPIO_FN(RSPI_SSL0_A), GPIO_FN(LCDVCPWC_1),
	GPIO_FN(DBGMD10), GPIO_FN(PORT6_BBIF2_TSYNC1), GPIO_FN(PORT6_FMSISLD), GPIO_FN(RSPI_SSL1_A), GPIO_FN(LCDVEPWC_1),
	GPIO_FN(FSIAOLR),
	GPIO_FN(FSIAOBT),
	GPIO_FN(FSIAOSLD), GPIO_FN(PORT9_FSIASPDIF),

	GPIO_FN(FSIAOMC), GPIO_FN(PORT10_SCIFA5_RXD),
	GPIO_FN(FSIACK),
	GPIO_FN(FSIAILR), GPIO_FN(PORT12_SCIFA4_RXD), GPIO_FN(LCDRS_1), GPIO_FN(LCDDISP_1),
	GPIO_FN(FSIAIBT), GPIO_FN(PORT13_SCIFA4_TXD), GPIO_FN(LCDRD_1),
	GPIO_FN(FMSOILR), GPIO_FN(FMSIILR), GPIO_FN(VIO_CKO1), GPIO_FN(LCDD23_1),
	GPIO_FN(FMSOIBT), GPIO_FN(FMSIIBT), GPIO_FN(VIO_CKO2), GPIO_FN(LCDD22_1),
	GPIO_FN(FMSOOLR), GPIO_FN(FMSIOLR),
	GPIO_FN(FMSOOBT), GPIO_FN(FMSIOBT),
	GPIO_FN(FMSOSLD), GPIO_FN(PORT18_FSIASPDIF),
	GPIO_FN(FMSICK), GPIO_FN(PORT19_CS5A_),

	GPIO_FN(FMSOCK), GPIO_FN(PORT20_SCIFA5_TXD),
	GPIO_FN(SCIFA1_CTS_), GPIO_FN(PORT21_SCIFA4_SCK), GPIO_FN(TPU0TO1), GPIO_FN(VIO_FIELD_1), GPIO_FN(STP_IPD5_0), GPIO_FN(LCDD10_1),
	GPIO_FN(PORT22_SCIFA2_SCK), GPIO_FN(PORT22_SIM_D), GPIO_FN(PORT22_VIO_D13_0),
	GPIO_FN(SCIFA1_RTS_), GPIO_FN(PORT23_SCIFA5_SCK), GPIO_FN(TPU0TO0), GPIO_FN(VIO_CKO_1), GPIO_FN(STP_IPD2_0), GPIO_FN(LCDD7_1),
	GPIO_FN(PORT24_VIO_D15_0), GPIO_FN(VIO_D7_1), GPIO_FN(SCIFA6_SCK), GPIO_FN(PORT24_SDHICD2),
	GPIO_FN(PORT25_VIO_D14_0), GPIO_FN(VIO_D6_1), GPIO_FN(SCIFA6_RXD), GPIO_FN(PORT25_SDHIWP2),
	GPIO_FN(PORT26_VIO_D13_0), GPIO_FN(VIO_D5_1), GPIO_FN(SCIFA6_TXD),
	GPIO_FN(VIO_D7_0),
	GPIO_FN(VIO_D6_0),
	GPIO_FN(VIO_D5_0),

	GPIO_FN(VIO_D4_0),
	GPIO_FN(VIO_D3_0),
	GPIO_FN(VIO_D2_0),
	GPIO_FN(VIO_D1_0),
	GPIO_FN(VIO_D0_0),
	GPIO_FN(VIO_CLK_0),
	GPIO_FN(VIO_CKO),
	GPIO_FN(VIO_HD_0),
	GPIO_FN(VIO_FIELD_0),
	GPIO_FN(VIO_VD_0),

	GPIO_FN(PORT40_LCDD18_0), GPIO_FN(RSPI_CK_A), GPIO_FN(LCDLCLK_1),
	GPIO_FN(LCDD17_0), GPIO_FN(MSIOF2_SS1),
	GPIO_FN(LCDD16_0), GPIO_FN(MSIOF2_MCK1),
	GPIO_FN(LCDD15_0), GPIO_FN(MSIOF2_MCK0), GPIO_FN(PORT43_KEYIN0), GPIO_FN(DV_D15),
	GPIO_FN(LCDD14_0), GPIO_FN(MSIOF2_RSYNC), GPIO_FN(PORT44_KEYIN1), GPIO_FN(DV_D14),
	GPIO_FN(LCDD13_0), GPIO_FN(MSIOF2_RSCK), GPIO_FN(PORT45_KEYIN2), GPIO_FN(DV_D13),
	GPIO_FN(LCDD12_0), GPIO_FN(PORT46_KEYIN3), GPIO_FN(DV_D12),
	GPIO_FN(LCDD11_0), GPIO_FN(KEYIN4), GPIO_FN(DV_D11),
	GPIO_FN(LCDD10_0), GPIO_FN(KEYIN5), GPIO_FN(DV_D10),
	GPIO_FN(LCDD9_0), GPIO_FN(KEYIN6), GPIO_FN(DV_D9),

	GPIO_FN(LCDD8_0), GPIO_FN(KEYIN7), GPIO_FN(DV_D8),
	GPIO_FN(LCDD7_0), GPIO_FN(KEYOUT0), GPIO_FN(DV_D7),
	GPIO_FN(LCDD6_0), GPIO_FN(KEYOUT1), GPIO_FN(DV_D6),
	GPIO_FN(LCDD5_0), GPIO_FN(KEYOUT2), GPIO_FN(DV_D5),
	GPIO_FN(LCDD4_0), GPIO_FN(KEYOUT3), GPIO_FN(DV_D4),
	GPIO_FN(LCDD3_0), GPIO_FN(KEYOUT4), GPIO_FN(PORT55_KEYIN3), GPIO_FN(DV_D3),
	GPIO_FN(LCDD2_0), GPIO_FN(KEYOUT5), GPIO_FN(PORT56_KEYIN2), GPIO_FN(DV_D2),
	GPIO_FN(LCDD1_0), GPIO_FN(KEYOUT6), GPIO_FN(PORT57_KEYIN1), GPIO_FN(DV_D1),
	GPIO_FN(LCDD0_0), GPIO_FN(KEYOUT7), GPIO_FN(PORT58_KEYIN0), GPIO_FN(DV_D0),
	GPIO_FN(LCDVCPWC_0), GPIO_FN(PORT59_BBIF2_TSCK1), GPIO_FN(RSPI_MOSI_A),

	GPIO_FN(LCDVEPWC_0), GPIO_FN(PORT60_BBIF2_RXD), GPIO_FN(RSPI_MISO_A),
	GPIO_FN(LCDDON_0), GPIO_FN(MSIOF2_TXD),
	GPIO_FN(LCDDCK_0), GPIO_FN(LCDWR_0), GPIO_FN(DV_CLK),
	GPIO_FN(LCDVSYN_0), GPIO_FN(DV_VSYNC),
	GPIO_FN(LCDHSYN_0), GPIO_FN(LCDCS_0), GPIO_FN(DV_HSYNC),
	GPIO_FN(LCDDISP_0), GPIO_FN(MSIOF2_TSCK), GPIO_FN(LCDRS_0),
	GPIO_FN(MEMC_INT), GPIO_FN(PORT66_TPU0TO2), GPIO_FN(PORT66_MMCCLK0), GPIO_FN(SDHICLK1),
	GPIO_FN(MEMC_CS0), GPIO_FN(PORT67_MSIOF1_SS1), GPIO_FN(PORT67_MMCCMD0), GPIO_FN(SDHICMD1),
	GPIO_FN(MEMC_AD8), GPIO_FN(MSIOF1_RSCK), GPIO_FN(PORT68_MMCD0_0), GPIO_FN(SDHID1_0),
	GPIO_FN(MEMC_AD9), GPIO_FN(MSIOF1_RSYNC), GPIO_FN(PORT69_MMCD0_1), GPIO_FN(SDHID1_1),

	GPIO_FN(MEMC_AD10), GPIO_FN(MSIOF1_MCK0), GPIO_FN(PORT70_MMCD0_2), GPIO_FN(SDHID1_2),
	GPIO_FN(MEMC_AD11), GPIO_FN(MSIOF1_MCK1), GPIO_FN(PORT71_MMCD0_3), GPIO_FN(SDHID1_3),
	GPIO_FN(MEMC_AD12), GPIO_FN(PORT72_MSIOF1_TSCK), GPIO_FN(PORT72_MMCD0_4), GPIO_FN(SDHICD1),
	GPIO_FN(MEMC_AD13), GPIO_FN(PORT73_MSIOF1_TSYNC), GPIO_FN(PORT73_MMCD0_5), GPIO_FN(SDHIWP1),
	GPIO_FN(MEMC_AD14), GPIO_FN(PORT74_MSIOF1_TXD), GPIO_FN(PORT74_MMCD0_6), GPIO_FN(STP_IPD7_1), GPIO_FN(LCDD21_1),
	GPIO_FN(MEMC_AD15), GPIO_FN(PORT75_MSIOF1_RXD), GPIO_FN(PORT75_MMCD0_7), GPIO_FN(STP_IPD6_1), GPIO_FN(LCDD20_1),
	GPIO_FN(SDHICMD0),
	GPIO_FN(SDHID0_0),
	GPIO_FN(SDHID0_1),
	GPIO_FN(SDHID0_2),

	GPIO_FN(SDHID0_3),
	GPIO_FN(SDHICD0),
	GPIO_FN(SDHICLK0),
	GPIO_FN(SDHIWP0),
	GPIO_FN(RESETOUTS_),
	GPIO_FN(PPON_0),
	GPIO_FN(OCI_0),
	GPIO_FN(PPON_1),
	GPIO_FN(OCI_1),
	GPIO_FN(DREQ0), GPIO_FN(PORT89_BBIF2_TSCK1), GPIO_FN(RSPI_SSL3_A),

	GPIO_FN(DACK0), GPIO_FN(PORT90_BBIF2_RXD), GPIO_FN(RSPI_SSL2_A), GPIO_FN(PORT90_WAIT_),
	GPIO_FN(MEMC_AD0), GPIO_FN(BBIF1_RXD), GPIO_FN(PORT91_SCIFA5_TXD), GPIO_FN(LCDD5_1),
	GPIO_FN(MEMC_AD1), GPIO_FN(BBIF1_TSYNC), GPIO_FN(PORT92_SCIFA5_RXD), GPIO_FN(STP_IPD1_0), GPIO_FN(LCDD6_1),
	GPIO_FN(MEMC_AD2), GPIO_FN(BBIF1_TSCK), GPIO_FN(PORT93_SCIFA4_TXD), GPIO_FN(STP_IPD3_0), GPIO_FN(LCDD8_1),
	GPIO_FN(MEMC_AD3), GPIO_FN(BBIF1_TXD), GPIO_FN(PORT94_SCIFA4_RXD), GPIO_FN(STP_IPD4_0), GPIO_FN(LCDD9_1),
	GPIO_FN(MEMC_CS1_MEMC_A1), GPIO_FN(SCIFA2_CTS_), GPIO_FN(STM_RST), GPIO_FN(PORT95_VIO_D14_0),
	GPIO_FN(MEMC_ADV_MEMC_DREQ0), GPIO_FN(SCIFA2_RTS_), GPIO_FN(STM_CLK), GPIO_FN(PORT96_VIO_D15_0),
	GPIO_FN(MEMC_AD4), GPIO_FN(BBIF1_RSCK), GPIO_FN(LCDCS_1), GPIO_FN(LCDHSYN_1),
	GPIO_FN(MEMC_AD5), GPIO_FN(BBIF1_RSYNC), GPIO_FN(LCDVSYN_1),
	GPIO_FN(MEMC_AD6), GPIO_FN(BBIF1_FLOW), GPIO_FN(LCDWR_1), GPIO_FN(LCDDCK_1),

	GPIO_FN(MEMC_AD7), GPIO_FN(BB_RX_FLOW_N), GPIO_FN(LCDDON_1),
	GPIO_FN(FCE0_),
	GPIO_FN(FRB), GPIO_FN(PORT102_LCDLCLK_0),
	GPIO_FN(CS5B_), GPIO_FN(FCE1_), GPIO_FN(PORT103_MMCCLK0),
	GPIO_FN(CS6A_), GPIO_FN(PORT104_MMCCMD0),
	GPIO_FN(PORT105_CS5A_), GPIO_FN(PORT105_SCIFA3_RTS_),
	GPIO_FN(IOIS16_), GPIO_FN(EXBUF_ENB_),
	GPIO_FN(WE3_),
	GPIO_FN(WE2_),
	GPIO_FN(CS0_),

	GPIO_FN(CS2_),
	GPIO_FN(CS4_),
	GPIO_FN(WE1_),
	GPIO_FN(WE0_FWE),
	GPIO_FN(RDWR),
	GPIO_FN(RD_FSC),
	GPIO_FN(A25), GPIO_FN(MSIOF0_SS2), GPIO_FN(PORT116_MSIOF1_SS2), GPIO_FN(PORT116_SCIFA3_SCK),
	GPIO_FN(A24), GPIO_FN(MSIOF0_SS1), GPIO_FN(PORT117_MSIOF1_SS1), GPIO_FN(PORT117_SCIFA3_CTS_),
	GPIO_FN(A23), GPIO_FN(MSIOF0_MCK1), GPIO_FN(PORT118_MSIOF1_RXD),
	GPIO_FN(A22), GPIO_FN(MSIOF0_MCK0), GPIO_FN(PORT119_MSIOF1_TXD),

	GPIO_FN(A21), GPIO_FN(MSIOF0_RSYNC), GPIO_FN(PORT120_MSIOF1_TSYNC),
	GPIO_FN(A20), GPIO_FN(MSIOF0_RSCK), GPIO_FN(PORT121_MSIOF1_TSCK),
	GPIO_FN(A19), GPIO_FN(MSIOF0_RXD),
	GPIO_FN(A18), GPIO_FN(MSIOF0_TSCK),
	GPIO_FN(A17), GPIO_FN(MSIOF0_TSYNC),
	GPIO_FN(A16),
	GPIO_FN(A15),
	GPIO_FN(A14),
	GPIO_FN(A13),
	GPIO_FN(A12),

	GPIO_FN(A11),
	GPIO_FN(A10),
	GPIO_FN(A9),
	GPIO_FN(A8),
	GPIO_FN(A7),
	GPIO_FN(A6),
	GPIO_FN(A5_FCDE),
	GPIO_FN(A4_FOE),
	GPIO_FN(A3),
	GPIO_FN(A2),

	GPIO_FN(A1),
	GPIO_FN(CKO),
	GPIO_FN(D15), GPIO_FN(PORT142_MMCD0_7),
	GPIO_FN(D14), GPIO_FN(PORT143_MMCD0_6),
	GPIO_FN(D12), GPIO_FN(PORT144_MMCD0_5),
	GPIO_FN(D13), GPIO_FN(PORT145_MMCD0_4),
	GPIO_FN(D11), GPIO_FN(PORT146_MMCD0_3),
	GPIO_FN(D10), GPIO_FN(PORT147_MMCD0_2),
	GPIO_FN(D9), GPIO_FN(PORT148_MMCD0_1),
	GPIO_FN(D8), GPIO_FN(PORT149_MMCD0_0),

	GPIO_FN(D7),
	GPIO_FN(D6),
	GPIO_FN(D5),
	GPIO_FN(D4),
	GPIO_FN(D3),
	GPIO_FN(D2),
	GPIO_FN(D1),
	GPIO_FN(D0),
	GPIO_FN(D31), GPIO_FN(PORT158_SCIFA3_SCK), GPIO_FN(REF125CK), GPIO_FN(PORT158_LCDD21_0), GPIO_FN(IRDA_FIRSEL), GPIO_FN(IDED15),
	GPIO_FN(D30), GPIO_FN(PORT159_SCIFA3_RXD), GPIO_FN(REF50CK), GPIO_FN(PORT159_LCDD23_0), GPIO_FN(IDED14),

	GPIO_FN(D29), GPIO_FN(PORT160_SCIFA3_TXD), GPIO_FN(PORT160_LCDD22_0), GPIO_FN(VIO_HD_1), GPIO_FN(IDED13),
	GPIO_FN(D28), GPIO_FN(PORT161_SCIFA3_RTS_), GPIO_FN(ET_RX_DV), GPIO_FN(PORT161_LCDD20_0), GPIO_FN(IRDA_IN), GPIO_FN(IDED12),
	GPIO_FN(D27), GPIO_FN(PORT162_SCIFA3_CTS_), GPIO_FN(PORT162_LCDD19_0), GPIO_FN(IRDA_OUT), GPIO_FN(IDED11),
	GPIO_FN(D26), GPIO_FN(MSIOF2_SS2), GPIO_FN(ET_COL), GPIO_FN(PORT163_LCDD18_0), GPIO_FN(IROUT), GPIO_FN(IDED10),
	GPIO_FN(D25), GPIO_FN(MSIOF2_TSYNC), GPIO_FN(ET_PHY_INT), GPIO_FN(LCDRD_0), GPIO_FN(IDED9),
	GPIO_FN(D24), GPIO_FN(MSIOF2_RXD), GPIO_FN(PORT165_LCDLCLK_0), GPIO_FN(IDED8),
	GPIO_FN(D21), GPIO_FN(ET_ETXD5), GPIO_FN(IDED5),
	GPIO_FN(D20), GPIO_FN(ET_ETXD4), GPIO_FN(IDED4),
	GPIO_FN(D19), GPIO_FN(ET_ETXD3), GPIO_FN(IDED3),
	GPIO_FN(D18), GPIO_FN(ET_ETXD2), GPIO_FN(IDED2),

	GPIO_FN(D17), GPIO_FN(ET_ETXD1), GPIO_FN(IDED1),
	GPIO_FN(D16), GPIO_FN(ET_ETXD0), GPIO_FN(IDED0),
	GPIO_FN(D23), GPIO_FN(PORT172_SCIFB_RTS_), GPIO_FN(ET_ETXD7), GPIO_FN(IDED7),
	GPIO_FN(D22), GPIO_FN(PORT173_SCIFB_CTS_), GPIO_FN(ET_ETXD6), GPIO_FN(IDED6),
	GPIO_FN(A26), GPIO_FN(MSIOF0_TXD), GPIO_FN(ET_RX_CLK), GPIO_FN(PORT174_SCIFA3_RXD),
	GPIO_FN(A0), GPIO_FN(BS), GPIO_FN(ET_MAGIC), GPIO_FN(PORT175_SCIFA3_TXD),
	GPIO_FN(ET_GTX_CLK),
	GPIO_FN(PORT177_WAIT_), GPIO_FN(ET_LINK), GPIO_FN(IDEIOWR_), GPIO_FN(PORT177_SDHIWP2),
	GPIO_FN(VIO_D12_0), GPIO_FN(VIO_D4_1), GPIO_FN(IDEIORD_),
	GPIO_FN(VIO_D11_0), GPIO_FN(VIO_D3_1), GPIO_FN(IDEIORDY),

	GPIO_FN(VIO_D10_0), GPIO_FN(TPU0TO3), GPIO_FN(VIO_D2_1), GPIO_FN(IDEINT),
	GPIO_FN(VIO_D9_0), GPIO_FN(VIO_D1_1), GPIO_FN(IDERST_),
	GPIO_FN(VIO_D8_0), GPIO_FN(VIO_D0_1), GPIO_FN(DIRECTION),
	GPIO_FN(DREQ1), GPIO_FN(PORT183_BBIF2_TXD1), GPIO_FN(ET_TX_EN),
	GPIO_FN(DACK1), GPIO_FN(PORT184_BBIF2_TSYNC1), GPIO_FN(ET_TX_CLK),
	GPIO_FN(SCIFA1_SCK), GPIO_FN(ET_ERXD0), GPIO_FN(STP_IPCLK_1),
	GPIO_FN(PORT186_SCIFB_RTS_), GPIO_FN(ET_ERXD1), GPIO_FN(PORT186_STP_IPD0_1),
	GPIO_FN(PORT187_SCIFB_CTS_), GPIO_FN(ET_ERXD2), GPIO_FN(PORT187_STP_IPEN_1),
	GPIO_FN(SCIFA0_SCK), GPIO_FN(ET_ERXD3), GPIO_FN(STP_IPSYNC_1),
	GPIO_FN(ET_ERXD4), GPIO_FN(STP_IPCLK_0),

	GPIO_FN(PORT190_SCIFB_SCK), GPIO_FN(ET_ERXD5), GPIO_FN(STP_IPD0_0),
	GPIO_FN(PORT191_SCIFB_RXD), GPIO_FN(ET_ERXD6), GPIO_FN(STP_IPEN_0),
	GPIO_FN(PORT192_SCIFB_TXD), GPIO_FN(ET_ERXD7), GPIO_FN(STP_IPSYNC_0),
	GPIO_FN(SCIFA0_CTS_), GPIO_FN(RMII_CRS_DV), GPIO_FN(PORT193_STP_IPEN_1), GPIO_FN(LCDD17_1),
	GPIO_FN(SCIFA0_RTS_), GPIO_FN(RMII_RX_ER), GPIO_FN(PORT194_STP_IPD0_1), GPIO_FN(LCDD16_1),
	GPIO_FN(SCIFA1_RXD), GPIO_FN(RMII_RXD0), GPIO_FN(STP_IPD3_1), GPIO_FN(LCDD15_1),
	GPIO_FN(SCIFA1_TXD), GPIO_FN(RMII_RXD1), GPIO_FN(STP_IPD2_1), GPIO_FN(LCDD14_1),
	GPIO_FN(SCIFA0_RXD), GPIO_FN(VIO_CLK_1), GPIO_FN(STP_IPD5_1), GPIO_FN(LCDD19_1),
	GPIO_FN(SCIFA0_TXD), GPIO_FN(VIO_VD_1), GPIO_FN(STP_IPD4_1), GPIO_FN(LCDD18_1),
	GPIO_FN(MEMC_NWE), GPIO_FN(PORT199_SCIFA2_SCK), GPIO_FN(RMII_TX_EN), GPIO_FN(PORT199_SIM_D), GPIO_FN(STP_IPD1_1), GPIO_FN(LCDD13_1),

	GPIO_FN(MEMC_NOE), GPIO_FN(SCIFA2_RXD), GPIO_FN(RMII_TXD0), GPIO_FN(STP_IPD7_0), GPIO_FN(LCDD12_1),
	GPIO_FN(MEMC_WAIT_MEMC_DREQ1), GPIO_FN(SCIFA2_TXD), GPIO_FN(RMII_TXD1), GPIO_FN(STP_IPD6_0), GPIO_FN(LCDD11_1),
	GPIO_FN(MEME_BUSCLK_MEMC_A0), GPIO_FN(PORT202_MSIOF1_SS2), GPIO_FN(RMII_MDC), GPIO_FN(PORT202_TPU0TO2), GPIO_FN(IDECS0_), GPIO_FN(PORT202_SDHICD2),
	GPIO_FN(SDHICLK2),GPIO_FN(ET_TX_ER), GPIO_FN(IDEA2), GPIO_FN(PORT203_SCIFA4_TXD),
	GPIO_FN(SDHICMD2),GPIO_FN(ET_RX_ER), GPIO_FN(IDEA1), GPIO_FN(PORT204_SCIFA4_RXD),
	GPIO_FN(SDHID2_0),GPIO_FN(ET_CRS), GPIO_FN(IDEA0), GPIO_FN(PORT205_SCIFA4_SCK),
	GPIO_FN(SDHID2_1),GPIO_FN(ET_MDC), GPIO_FN(IODACK_), GPIO_FN(PORT206_SCIFA5_SCK),
	GPIO_FN(SDHID2_2),GPIO_FN(ET_MDIO), GPIO_FN(IODREQ), GPIO_FN(PORT207_SCIFA5_RXD),
	GPIO_FN(SDHID2_3),GPIO_FN(RMII_MDIO), GPIO_FN(IDECS1_), GPIO_FN(PORT208_SCIFA5_TXD),
	GPIO_FN(VBUS),
};

#define PORTCR(nr, reg)	\
	{ PINMUX_CFG_REG("PORT" nr "CR", reg, 8, 4) { \
		0, \
		/*0001*/ PORT##nr##_OUT , \
		/*0010*/ PORT##nr##_IN , 0, 0, 0, 0, 0, 0, 0, \
		/*1010*/ PORT##nr##_IN_PD, 0, 0, 0, \
		/*1110*/ PORT##nr##_IN_PU, 0, \
		PORT##nr##_FN0, PORT##nr##_FN1,	PORT##nr##_FN2, \
		PORT##nr##_FN3,	PORT##nr##_FN4, PORT##nr##_FN5, \
		PORT##nr##_FN6, PORT##nr##_FN7, 0, 0, 0, 0, 0, 0, 0, 0 } \
	}

static struct pinmux_cfg_reg pinmux_config_regs[] = {
	PORTCR(0, 0xe6050000), /* PORT0CR */
	PORTCR(1, 0xe6050001), /* PORT1CR */
	PORTCR(2, 0xe6050002), /* PORT2CR */
	PORTCR(3, 0xe6050003), /* PORT3CR */
	PORTCR(4, 0xe6050004), /* PORT4CR */
	PORTCR(5, 0xe6050005), /* PORT5CR */
	PORTCR(6, 0xe6050006), /* PORT6CR */
	PORTCR(7, 0xe6050007), /* PORT7CR */
	PORTCR(8, 0xe6050008), /* PORT8CR */
	PORTCR(9, 0xe6050009), /* PORT9CR */
	PORTCR(10, 0xe605000a), /* PORT10CR */
	PORTCR(11, 0xe605000b), /* PORT11CR */
	PORTCR(12, 0xe605000c), /* PORT12CR */
	PORTCR(13, 0xe605000d), /* PORT13CR */
	PORTCR(14, 0xe605000e), /* PORT14CR */
	PORTCR(15, 0xe605000f), /* PORT15CR */
	PORTCR(16, 0xe6050010), /* PORT16CR */
	PORTCR(17, 0xe6050011), /* PORT17CR */
	PORTCR(18, 0xe6050012), /* PORT18CR */
	PORTCR(19, 0xe6050013), /* PORT19CR */
	PORTCR(20, 0xe6050014), /* PORT20CR */
	PORTCR(21, 0xe6050015), /* PORT21CR */
	PORTCR(22, 0xe6050016), /* PORT22CR */
	PORTCR(23, 0xe6050017), /* PORT23CR */
	PORTCR(24, 0xe6050018), /* PORT24CR */
	PORTCR(25, 0xe6050019), /* PORT25CR */
	PORTCR(26, 0xe605001a), /* PORT26CR */
	PORTCR(27, 0xe605001b), /* PORT27CR */
	PORTCR(28, 0xe605001c), /* PORT28CR */
	PORTCR(29, 0xe605001d), /* PORT29CR */
	PORTCR(30, 0xe605001e), /* PORT30CR */
	PORTCR(31, 0xe605001f), /* PORT31CR */
	PORTCR(32, 0xe6050020), /* PORT32CR */
	PORTCR(33, 0xe6050021), /* PORT33CR */
	PORTCR(34, 0xe6050022), /* PORT34CR */
	PORTCR(35, 0xe6050023), /* PORT35CR */
	PORTCR(36, 0xe6050024), /* PORT36CR */
	PORTCR(37, 0xe6050025), /* PORT37CR */
	PORTCR(38, 0xe6050026), /* PORT38CR */
	PORTCR(39, 0xe6050027), /* PORT39CR */
	PORTCR(40, 0xe6050028), /* PORT40CR */
	PORTCR(41, 0xe6050029), /* PORT41CR */
	PORTCR(42, 0xe605002a), /* PORT42CR */
	PORTCR(43, 0xe605002b), /* PORT43CR */
	PORTCR(44, 0xe605002c), /* PORT44CR */
	PORTCR(45, 0xe605002d), /* PORT45CR */
	PORTCR(46, 0xe605002e), /* PORT46CR */
	PORTCR(47, 0xe605002f), /* PORT47CR */
	PORTCR(48, 0xe6050030), /* PORT48CR */
	PORTCR(49, 0xe6050031), /* PORT49CR */
	PORTCR(50, 0xe6050032), /* PORT50CR */
	PORTCR(51, 0xe6050033), /* PORT51CR */
	PORTCR(52, 0xe6050034), /* PORT52CR */
	PORTCR(53, 0xe6050035), /* PORT53CR */
	PORTCR(54, 0xe6050036), /* PORT54CR */
	PORTCR(55, 0xe6050037), /* PORT55CR */
	PORTCR(56, 0xe6050038), /* PORT56CR */
	PORTCR(57, 0xe6050039), /* PORT57CR */
	PORTCR(58, 0xe605003a), /* PORT58CR */
	PORTCR(59, 0xe605003b), /* PORT59CR */
	PORTCR(60, 0xe605003c), /* PORT60CR */
	PORTCR(61, 0xe605003d), /* PORT61CR */
	PORTCR(62, 0xe605003e), /* PORT62CR */
	PORTCR(63, 0xe605003f), /* PORT63CR */
	PORTCR(64, 0xe6050040), /* PORT64CR */
	PORTCR(65, 0xe6050041), /* PORT65CR */
	PORTCR(66, 0xe6050042), /* PORT66CR */
	PORTCR(67, 0xe6050043), /* PORT67CR */
	PORTCR(68, 0xe6050044), /* PORT68CR */
	PORTCR(69, 0xe6050045), /* PORT69CR */
	PORTCR(70, 0xe6050046), /* PORT70CR */
	PORTCR(71, 0xe6050047), /* PORT71CR */
	PORTCR(72, 0xe6050048), /* PORT72CR */
	PORTCR(73, 0xe6050049), /* PORT73CR */
	PORTCR(74, 0xe605004a), /* PORT74CR */
	PORTCR(75, 0xe605004b), /* PORT75CR */
	PORTCR(76, 0xe605004c), /* PORT76CR */
	PORTCR(77, 0xe605004d), /* PORT77CR */
	PORTCR(78, 0xe605004e), /* PORT78CR */
	PORTCR(79, 0xe605004f), /* PORT79CR */
	PORTCR(80, 0xe6050050), /* PORT80CR */
	PORTCR(81, 0xe6050051), /* PORT81CR */
	PORTCR(82, 0xe6050052), /* PORT82CR */
	PORTCR(83, 0xe6050053), /* PORT83CR */

	PORTCR(84, 0xe6051054), /* PORT84CR */
	PORTCR(85, 0xe6051055), /* PORT85CR */
	PORTCR(86, 0xe6051056), /* PORT86CR */
	PORTCR(87, 0xe6051057), /* PORT87CR */
	PORTCR(88, 0xe6051058), /* PORT88CR */
	PORTCR(89, 0xe6051059), /* PORT89CR */
	PORTCR(90, 0xe605105a), /* PORT90CR */
	PORTCR(91, 0xe605105b), /* PORT91CR */
	PORTCR(92, 0xe605105c), /* PORT92CR */
	PORTCR(93, 0xe605105d), /* PORT93CR */
	PORTCR(94, 0xe605105e), /* PORT94CR */
	PORTCR(95, 0xe605105f), /* PORT95CR */
	PORTCR(96, 0xe6051060), /* PORT96CR */
	PORTCR(97, 0xe6051061), /* PORT97CR */
	PORTCR(98, 0xe6051062), /* PORT98CR */
	PORTCR(99, 0xe6051063), /* PORT99CR */
	PORTCR(100, 0xe6051064), /* PORT100CR */
	PORTCR(101, 0xe6051065), /* PORT101CR */
	PORTCR(102, 0xe6051066), /* PORT102CR */
	PORTCR(103, 0xe6051067), /* PORT103CR */
	PORTCR(104, 0xe6051068), /* PORT104CR */
	PORTCR(105, 0xe6051069), /* PORT105CR */
	PORTCR(106, 0xe605106a), /* PORT106CR */
	PORTCR(107, 0xe605106b), /* PORT107CR */
	PORTCR(108, 0xe605106c), /* PORT108CR */
	PORTCR(109, 0xe605106d), /* PORT109CR */
	PORTCR(110, 0xe605106e), /* PORT110CR */
	PORTCR(111, 0xe605106f), /* PORT111CR */
	PORTCR(112, 0xe6051070), /* PORT112CR */
	PORTCR(113, 0xe6051071), /* PORT113CR */
	PORTCR(114, 0xe6051072), /* PORT114CR */

	PORTCR(115, 0xe6052073), /* PORT115CR */
	PORTCR(116, 0xe6052074), /* PORT116CR */
	PORTCR(117, 0xe6052075), /* PORT117CR */
	PORTCR(118, 0xe6052076), /* PORT118CR */
	PORTCR(119, 0xe6052077), /* PORT119CR */
	PORTCR(120, 0xe6052078), /* PORT120CR */
	PORTCR(121, 0xe6052079), /* PORT121CR */
	PORTCR(122, 0xe605207a), /* PORT122CR */
	PORTCR(123, 0xe605207b), /* PORT123CR */
	PORTCR(124, 0xe605207c), /* PORT124CR */
	PORTCR(125, 0xe605207d), /* PORT125CR */
	PORTCR(126, 0xe605207e), /* PORT126CR */
	PORTCR(127, 0xe605207f), /* PORT127CR */
	PORTCR(128, 0xe6052080), /* PORT128CR */
	PORTCR(129, 0xe6052081), /* PORT129CR */
	PORTCR(130, 0xe6052082), /* PORT130CR */
	PORTCR(131, 0xe6052083), /* PORT131CR */
	PORTCR(132, 0xe6052084), /* PORT132CR */
	PORTCR(133, 0xe6052085), /* PORT133CR */
	PORTCR(134, 0xe6052086), /* PORT134CR */
	PORTCR(135, 0xe6052087), /* PORT135CR */
	PORTCR(136, 0xe6052088), /* PORT136CR */
	PORTCR(137, 0xe6052089), /* PORT137CR */
	PORTCR(138, 0xe605208a), /* PORT138CR */
	PORTCR(139, 0xe605208b), /* PORT139CR */
	PORTCR(140, 0xe605208c), /* PORT140CR */
	PORTCR(141, 0xe605208d), /* PORT141CR */
	PORTCR(142, 0xe605208e), /* PORT142CR */
	PORTCR(143, 0xe605208f), /* PORT143CR */
	PORTCR(144, 0xe6052090), /* PORT144CR */
	PORTCR(145, 0xe6052091), /* PORT145CR */
	PORTCR(146, 0xe6052092), /* PORT146CR */
	PORTCR(147, 0xe6052093), /* PORT147CR */
	PORTCR(148, 0xe6052094), /* PORT148CR */
	PORTCR(149, 0xe6052095), /* PORT149CR */
	PORTCR(150, 0xe6052096), /* PORT150CR */
	PORTCR(151, 0xe6052097), /* PORT151CR */
	PORTCR(152, 0xe6052098), /* PORT152CR */
	PORTCR(153, 0xe6052099), /* PORT153CR */
	PORTCR(154, 0xe605209a), /* PORT154CR */
	PORTCR(155, 0xe605209b), /* PORT155CR */
	PORTCR(156, 0xe605209c), /* PORT156CR */
	PORTCR(157, 0xe605209d), /* PORT157CR */
	PORTCR(158, 0xe605209e), /* PORT158CR */
	PORTCR(159, 0xe605209f), /* PORT159CR */
	PORTCR(160, 0xe60520a0), /* PORT160CR */
	PORTCR(161, 0xe60520a1), /* PORT161CR */
	PORTCR(162, 0xe60520a2), /* PORT162CR */
	PORTCR(163, 0xe60520a3), /* PORT163CR */
	PORTCR(164, 0xe60520a4), /* PORT164CR */
	PORTCR(165, 0xe60520a5), /* PORT165CR */
	PORTCR(166, 0xe60520a6), /* PORT166CR */
	PORTCR(167, 0xe60520a7), /* PORT167CR */
	PORTCR(168, 0xe60520a8), /* PORT168CR */
	PORTCR(169, 0xe60520a9), /* PORT169CR */
	PORTCR(170, 0xe60520aa), /* PORT170CR */
	PORTCR(171, 0xe60520ab), /* PORT171CR */
	PORTCR(172, 0xe60520ac), /* PORT172CR */
	PORTCR(173, 0xe60520ad), /* PORT173CR */
	PORTCR(174, 0xe60520ae), /* PORT174CR */
	PORTCR(175, 0xe60520af), /* PORT175CR */
	PORTCR(176, 0xe60520b0), /* PORT176CR */
	PORTCR(177, 0xe60520b1), /* PORT177CR */
	PORTCR(178, 0xe60520b2), /* PORT178CR */
	PORTCR(179, 0xe60520b3), /* PORT179CR */
	PORTCR(180, 0xe60520b4), /* PORT180CR */
	PORTCR(181, 0xe60520b5), /* PORT181CR */
	PORTCR(182, 0xe60520b6), /* PORT182CR */
	PORTCR(183, 0xe60520b7), /* PORT183CR */
	PORTCR(184, 0xe60520b8), /* PORT184CR */
	PORTCR(185, 0xe60520b9), /* PORT185CR */
	PORTCR(186, 0xe60520ba), /* PORT186CR */
	PORTCR(187, 0xe60520bb), /* PORT187CR */
	PORTCR(188, 0xe60520bc), /* PORT188CR */
	PORTCR(189, 0xe60520bd), /* PORT189CR */
	PORTCR(190, 0xe60520be), /* PORT190CR */
	PORTCR(191, 0xe60520bf), /* PORT191CR */
	PORTCR(192, 0xe60520c0), /* PORT192CR */
	PORTCR(193, 0xe60520c1), /* PORT193CR */
	PORTCR(194, 0xe60520c2), /* PORT194CR */
	PORTCR(195, 0xe60520c3), /* PORT195CR */
	PORTCR(196, 0xe60520c4), /* PORT196CR */
	PORTCR(197, 0xe60520c5), /* PORT197CR */
	PORTCR(198, 0xe60520c6), /* PORT198CR */
	PORTCR(199, 0xe60520c7), /* PORT199CR */
	PORTCR(200, 0xe60520c8), /* PORT200CR */
	PORTCR(201, 0xe60520c9), /* PORT201CR */
	PORTCR(202, 0xe60520ca), /* PORT202CR */
	PORTCR(203, 0xe60520cb), /* PORT203CR */
	PORTCR(204, 0xe60520cc), /* PORT204CR */
	PORTCR(205, 0xe60520cd), /* PORT205CR */
	PORTCR(206, 0xe60520ce), /* PORT206CR */
	PORTCR(207, 0xe60520cf), /* PORT207CR */
	PORTCR(208, 0xe60520d0), /* PORT208CR */
	PORTCR(209, 0xe60520d1), /* PORT209CR */

	PORTCR(210, 0xe60530d2), /* PORT210CR */
	PORTCR(211, 0xe60530d3), /* PORT211CR */

	{ PINMUX_CFG_REG("MSEL1CR", 0xe605800c, 32, 1) {
			MSEL1CR_31_0,	MSEL1CR_31_1,
			MSEL1CR_30_0,	MSEL1CR_30_1,
			MSEL1CR_29_0,	MSEL1CR_29_1,
			MSEL1CR_28_0,	MSEL1CR_28_1,
			MSEL1CR_27_0,	MSEL1CR_27_1,
			MSEL1CR_26_0,	MSEL1CR_26_1,
			0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			MSEL1CR_16_0,	MSEL1CR_16_1,
			MSEL1CR_15_0,	MSEL1CR_15_1,
			MSEL1CR_14_0,	MSEL1CR_14_1,
			MSEL1CR_13_0,	MSEL1CR_13_1,
			MSEL1CR_12_0,	MSEL1CR_12_1,
			0, 0, 0, 0,
			MSEL1CR_9_0,	MSEL1CR_9_1,
			0, 0,
			MSEL1CR_7_0,	MSEL1CR_7_1,
			MSEL1CR_6_0,	MSEL1CR_6_1,
			MSEL1CR_5_0,	MSEL1CR_5_1,
			MSEL1CR_4_0,	MSEL1CR_4_1,
			MSEL1CR_3_0,	MSEL1CR_3_1,
			MSEL1CR_2_0,	MSEL1CR_2_1,
			0, 0,
			MSEL1CR_0_0,	MSEL1CR_0_1,
		}
	},
	{ PINMUX_CFG_REG("MSEL3CR", 0xE6058020, 32, 1) {
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			MSEL3CR_15_0,	MSEL3CR_15_1,
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			MSEL3CR_6_0,	MSEL3CR_6_1,
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0,
			}
	},
	{ PINMUX_CFG_REG("MSEL4CR", 0xE6058024, 32, 1) {
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			0, 0, 0, 0, 0, 0, 0, 0,
			MSEL4CR_19_0,	MSEL4CR_19_1,
			MSEL4CR_18_0,	MSEL4CR_18_1,
			0, 0, 0, 0,
			MSEL4CR_15_0,	MSEL4CR_15_1,
			0, 0, 0, 0, 0, 0, 0, 0,
			MSEL4CR_10_0,	MSEL4CR_10_1,
			0, 0, 0, 0, 0, 0,
			MSEL4CR_6_0,	MSEL4CR_6_1,
			0, 0,
			MSEL4CR_4_0,	MSEL4CR_4_1,
			0, 0, 0, 0,
			MSEL4CR_1_0,	MSEL4CR_1_1,
			0, 0,
		}
	},
	{ PINMUX_CFG_REG("MSEL5CR", 0xE6058028, 32, 1) {
			MSEL5CR_31_0,	MSEL5CR_31_1,
			MSEL5CR_30_0,	MSEL5CR_30_1,
			MSEL5CR_29_0,	MSEL5CR_29_1,
			0, 0,
			MSEL5CR_27_0,	MSEL5CR_27_1,
			0, 0,
			MSEL5CR_25_0,	MSEL5CR_25_1,
			0, 0,
			MSEL5CR_23_0,	MSEL5CR_23_1,
			0, 0,
			MSEL5CR_21_0,	MSEL5CR_21_1,
			0, 0,
			MSEL5CR_19_0,	MSEL5CR_19_1,
			0, 0,
			MSEL5CR_17_0,	MSEL5CR_17_1,
			0, 0,
			MSEL5CR_15_0,	MSEL5CR_15_1,
			MSEL5CR_14_0,	MSEL5CR_14_1,
			MSEL5CR_13_0,	MSEL5CR_13_1,
			MSEL5CR_12_0,	MSEL5CR_12_1,
			MSEL5CR_11_0,	MSEL5CR_11_1,
			MSEL5CR_10_0,	MSEL5CR_10_1,
			0, 0,
			MSEL5CR_8_0,	MSEL5CR_8_1,
			MSEL5CR_7_0,	MSEL5CR_7_1,
			MSEL5CR_6_0,	MSEL5CR_6_1,
			MSEL5CR_5_0,	MSEL5CR_5_1,
			MSEL5CR_4_0,	MSEL5CR_4_1,
			MSEL5CR_3_0,	MSEL5CR_3_1,
			MSEL5CR_2_0,	MSEL5CR_2_1,
			0, 0,
			MSEL5CR_0_0,	MSEL5CR_0_1,
		}
	},
	{ },
};

#define PORT_DATA_REG(name, r, w) \
	PINMUX_DATA_REG_EXT(name, r, (r+0x100), (r+0x200), w)

static struct pinmux_data_reg pinmux_data_regs[] = {
	{ PORT_DATA_REG("PORTL031_000DR", 0xe6054000, 32) {
			PORT31_DATA, PORT30_DATA, PORT29_DATA, PORT28_DATA,
			PORT27_DATA, PORT26_DATA, PORT25_DATA, PORT24_DATA,
			PORT23_DATA, PORT22_DATA, PORT21_DATA, PORT20_DATA,
			PORT19_DATA, PORT18_DATA, PORT17_DATA, PORT16_DATA,
			PORT15_DATA, PORT14_DATA, PORT13_DATA, PORT12_DATA,
			PORT11_DATA, PORT10_DATA, PORT9_DATA, PORT8_DATA,
			PORT7_DATA, PORT6_DATA, PORT5_DATA, PORT4_DATA,
			PORT3_DATA, PORT2_DATA, PORT1_DATA, PORT0_DATA }
	},
	{ PORT_DATA_REG("PORTL063_032DR", 0xe6054004, 32) {
			PORT63_DATA, PORT62_DATA, PORT61_DATA, PORT60_DATA,
			PORT59_DATA, PORT58_DATA, PORT57_DATA, PORT56_DATA,
			PORT55_DATA, PORT54_DATA, PORT53_DATA, PORT52_DATA,
			PORT51_DATA, PORT50_DATA, PORT49_DATA, PORT48_DATA,
			PORT47_DATA, PORT46_DATA, PORT45_DATA, PORT44_DATA,
			PORT43_DATA, PORT42_DATA, PORT41_DATA, PORT40_DATA,
			PORT39_DATA, PORT38_DATA, PORT37_DATA, PORT36_DATA,
			PORT35_DATA, PORT34_DATA, PORT33_DATA, PORT32_DATA }
	},
	{ PORT_DATA_REG("PORTL095_064DR", 0xe6054008, 32) {
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			PORT83_DATA, PORT82_DATA, PORT81_DATA, PORT80_DATA,
			PORT79_DATA, PORT78_DATA, PORT77_DATA, PORT76_DATA,
			PORT75_DATA, PORT74_DATA, PORT73_DATA, PORT72_DATA,
			PORT71_DATA, PORT70_DATA, PORT69_DATA, PORT68_DATA,
			PORT67_DATA, PORT66_DATA, PORT65_DATA, PORT64_DATA }
	},
	{ PORT_DATA_REG("PORTD095_064DR", 0xe6055008, 32) {
			PORT95_DATA, PORT94_DATA, PORT93_DATA, PORT92_DATA,
			PORT91_DATA, PORT90_DATA, PORT89_DATA, PORT88_DATA,
			PORT87_DATA, PORT86_DATA, PORT85_DATA, PORT84_DATA,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0 }
	},
	{ PORT_DATA_REG("PORTD127_096DR", 0xe605500c, 32) {
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, PORT114_DATA, PORT113_DATA, PORT112_DATA,
			PORT111_DATA, PORT110_DATA, PORT109_DATA, PORT108_DATA,
			PORT107_DATA, PORT106_DATA, PORT105_DATA, PORT104_DATA,
			PORT103_DATA, PORT102_DATA, PORT101_DATA, PORT100_DATA,
			PORT99_DATA, PORT98_DATA, PORT97_DATA, PORT96_DATA }
	},
	{ PORT_DATA_REG("PORTR127_096DR", 0xe605600C, 32) {
			PORT127_DATA, PORT126_DATA, PORT125_DATA, PORT124_DATA,
			PORT123_DATA, PORT122_DATA, PORT121_DATA, PORT120_DATA,
			PORT119_DATA, PORT118_DATA, PORT117_DATA, PORT116_DATA,
			PORT115_DATA, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0 }
	},
	{ PORT_DATA_REG("PORTR159_128DR", 0xe6056010, 32) {
			PORT159_DATA, PORT158_DATA, PORT157_DATA, PORT156_DATA,
			PORT155_DATA, PORT154_DATA, PORT153_DATA, PORT152_DATA,
			PORT151_DATA, PORT150_DATA, PORT149_DATA, PORT148_DATA,
			PORT147_DATA, PORT146_DATA, PORT145_DATA, PORT144_DATA,
			PORT143_DATA, PORT142_DATA, PORT141_DATA, PORT140_DATA,
			PORT139_DATA, PORT138_DATA, PORT137_DATA, PORT136_DATA,
			PORT135_DATA, PORT134_DATA, PORT133_DATA, PORT132_DATA,
			PORT131_DATA, PORT130_DATA, PORT129_DATA, PORT128_DATA }
	},
	{ PORT_DATA_REG("PORTR191_160DR", 0xe6056014, 32) {
			PORT191_DATA, PORT190_DATA, PORT189_DATA, PORT188_DATA,
			PORT187_DATA, PORT186_DATA, PORT185_DATA, PORT184_DATA,
			PORT183_DATA, PORT182_DATA, PORT181_DATA, PORT180_DATA,
			PORT179_DATA, PORT178_DATA, PORT177_DATA, PORT176_DATA,
			PORT175_DATA, PORT174_DATA, PORT173_DATA, PORT172_DATA,
			PORT171_DATA, PORT170_DATA, PORT169_DATA, PORT168_DATA,
			PORT167_DATA, PORT166_DATA, PORT165_DATA, PORT164_DATA,
			PORT163_DATA, PORT162_DATA, PORT161_DATA, PORT160_DATA }
	},
	{ PORT_DATA_REG("PORTR223_192DR", 0xe6056018, 32) {
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, PORT209_DATA, PORT208_DATA,
			PORT207_DATA, PORT206_DATA, PORT205_DATA, PORT204_DATA,
			PORT203_DATA, PORT202_DATA, PORT201_DATA, PORT200_DATA,
			PORT199_DATA, PORT198_DATA, PORT197_DATA, PORT196_DATA,
			PORT195_DATA, PORT194_DATA, PORT193_DATA, PORT192_DATA }
	},
	{ PORT_DATA_REG("PORTU223_192DR", 0xe6057018, 32) {
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			PORT211_DATA, PORT210_DATA, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0,
			0, 0, 0, 0 }
	},
	{ },
};

#include <mach/irqs.h>
static struct pinmux_gpio_irq pinmux_gpio_irqs[] = {
	{ GPIO_PORT97, irqpin2irq(12) },
	{ GPIO_PORT98, irqpin2irq(13) },
	{ GPIO_PORT99, irqpin2irq(14) },
	{ GPIO_PORT100, irqpin2irq(15) },
};

static struct pinmux_info sh7740_pinmux_info = {
	.name = "sh7740_pfc",
	.reserved_id = PINMUX_RESERVED,
	.data = { PINMUX_DATA_BEGIN, PINMUX_DATA_END },
	.input = { PINMUX_INPUT_BEGIN, PINMUX_INPUT_END },
	.input_pu = { PINMUX_INPUT_PULLUP_BEGIN, PINMUX_INPUT_PULLUP_END },
	.input_pd = { PINMUX_INPUT_PULLDOWN_BEGIN, PINMUX_INPUT_PULLDOWN_END },
	.output = { PINMUX_OUTPUT_BEGIN, PINMUX_OUTPUT_END },
	.mark = { PINMUX_MARK_BEGIN, PINMUX_MARK_END },
	.function = { PINMUX_FUNCTION_BEGIN, PINMUX_FUNCTION_END },

	.first_gpio = GPIO_PORT0,
	.last_gpio = GPIO_FN_VBUS,

	.gpios = pinmux_gpios,
	.cfg_regs = pinmux_config_regs,
	.data_regs = pinmux_data_regs,

	.gpio_data = pinmux_data,
	.gpio_data_size = ARRAY_SIZE(pinmux_data),

	.gpio_irq = pinmux_gpio_irqs,
	.gpio_irq_size = ARRAY_SIZE(pinmux_gpio_irqs),
};

void sh7740_pinmux_init(void)
{
	register_pinmux(&sh7740_pinmux_info);
}
