/*
 * FSI-HDMI sound support
 *
 * Copyright (C) 2011 Atmark Techno, Inc.
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file "COPYING" in the main directory of this archive
 * for more details.
 */

#include <linux/module.h>
#include <linux/moduleparam.h>
#include <linux/platform_device.h>
#include <linux/i2c.h>
#include <linux/io.h>
#include <sound/core.h>
#include <sound/pcm.h>
#include <sound/soc.h>
#include <sound/soc-dapm.h>
#include <sound/initval.h>
#include <sound/sh_fsi.h>

static struct snd_soc_codec fsi_hdmi_dummy_codec;

static struct snd_soc_dai fsi_hdmi_dai = {
	.name = "FSI HDMI HiFi",
	.id = 1,
	.playback = {
		.stream_name = "Playback",
		.channels_min = 2,
		.channels_max = 2,
		.rates = SNDRV_PCM_RATE_48000,
		.formats = SNDRV_PCM_FMTBIT_S16_LE,
	},
};

static int fsi_hdmi_probe(struct platform_device *pdev)
{
	struct snd_soc_device *socdev = platform_get_drvdata(pdev);
	struct snd_soc_codec *codec;
	int ret;

	socdev->card->codec = codec = &fsi_hdmi_dummy_codec;

	/* register pcms */
	ret = snd_soc_new_pcms(socdev, SNDRV_DEFAULT_IDX1, SNDRV_DEFAULT_STR1);
	if (ret < 0) {
		dev_err(codec->dev, "failed to create pcms: %d\n", ret);
		return ret;
	}

	return 0;
}

static int fsi_hdmi_remove(struct platform_device *pdev)
{
	return 0;
}

static struct snd_soc_codec_device soc_codec_dev_fsi_hdmi = {
	.probe		= fsi_hdmi_probe,
	.remove		= fsi_hdmi_remove,
};

static int __devinit fsi_hdmi_codec_probe(struct platform_device *pdev)
{
	struct snd_soc_codec *codec = &fsi_hdmi_dummy_codec;
	int ret;

	memset(codec, 0, sizeof(struct snd_soc_codec));
	mutex_init(&codec->mutex);
	INIT_LIST_HEAD(&codec->dapm_widgets);
	INIT_LIST_HEAD(&codec->dapm_paths);

	codec->dev = &pdev->dev;
	codec->name = "FSI-HDMI";
	codec->owner = THIS_MODULE;
	codec->dai = &fsi_hdmi_dai;
	codec->num_dai = 1;

	fsi_hdmi_dai.dev = codec->dev;

	ret = snd_soc_register_codec(codec);
	if (ret !=0) {
		dev_err(codec->dev, "Failed to register codec: %d\n", ret);
		return ret;
	}

	ret = snd_soc_register_dai(&fsi_hdmi_dai);
	if (ret != 0) {
		dev_err(codec->dev, "Failed to register DAI: %d\n", ret);
		return ret;
	}

	return 0;
}

static int fsi_hdmi_codec_remove(struct platform_device *pdev)
{
	struct snd_soc_codec *codec = &fsi_hdmi_dummy_codec;
	snd_soc_unregister_dai(&fsi_hdmi_dai);
	snd_soc_unregister_codec(codec);
	return 0;
}

static struct platform_driver fsi_hdmi_codec_driver = {
	.driver = {
		.name = "fsi_hdmi_codec",
		.owner = THIS_MODULE,
	},
	.probe = fsi_hdmi_codec_probe,
	.remove = fsi_hdmi_codec_remove,
};

static int __init fsi_hdmi_codec_init(void)
{
	return platform_driver_register(&fsi_hdmi_codec_driver);
}

static void __exit fsi_hdmi_codec_exit(void)
{
	platform_driver_unregister(&fsi_hdmi_codec_driver);
}
module_init(fsi_hdmi_codec_init);
module_exit(fsi_hdmi_codec_exit);

/*****************************************************************/

static int fsi_hdmi_dai_init(struct snd_soc_codec *codec)
{
	return 0;
}

static struct snd_soc_dai_link fsi_dai_link = {
	.name		= "fsi_hdmi_codec",
	.stream_name	= "fsi_hdmi_codec",
	.cpu_dai	= &fsi_soc_dai[1],
	.codec_dai	= &fsi_hdmi_dai,
	.init		= fsi_hdmi_dai_init,
	.ops		= NULL,
};

static struct snd_soc_card fsi_soc_card  = {
	.name		= "FSI",
	.platform	= &fsi_soc_platform,
	.dai_link	= &fsi_dai_link,
	.num_links	= 1,
};

static struct snd_soc_device fsi_snd_devdata = {
	.card		= &fsi_soc_card,
	.codec_dev	= &soc_codec_dev_fsi_hdmi,
};

static struct platform_device *fsi_snd_device;

static int __init fsi_hdmi_init(void)
{
	int ret = -ENOMEM;

	fsi_snd_device = platform_device_alloc("soc-audio", 1);
	if (!fsi_snd_device)
		goto out;

	platform_set_drvdata(fsi_snd_device,
			     &fsi_snd_devdata);
	fsi_snd_devdata.dev = &fsi_snd_device->dev;
	ret = platform_device_add(fsi_snd_device);

	if (ret)
		platform_device_put(fsi_snd_device);

out:
	return ret;
}

static void __exit fsi_hdmi_exit(void)
{
	platform_device_unregister(fsi_snd_device);
}

module_init(fsi_hdmi_init);
module_exit(fsi_hdmi_exit);

MODULE_LICENSE("GPL");
MODULE_DESCRIPTION("Generic SH4 FSI-HDMI sound card");
